.materialize-red {
  background-color: #e51c23 !important; }

.materialize-red-text {
  color: #e51c23 !important; }

/* Fills for SVG */
.materialize-red-fill {
  fill: #e51c23; }

/* Strokes for SVG */
.materialize-red-stroke {
  stroke: #e51c23; }

.materialize-red.lighten-5 {
  background-color: #fdeaeb !important; }

.materialize-red-text.text-lighten-5 {
  color: #fdeaeb !important; }

/* Fills for SVG */
.materialize-red-fill.fill-lighten-5 {
  fill: #fdeaeb; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-lighten-5 {
  stroke: #fdeaeb; }

.materialize-red.lighten-4 {
  background-color: #f8c1c3 !important; }

.materialize-red-text.text-lighten-4 {
  color: #f8c1c3 !important; }

/* Fills for SVG */
.materialize-red-fill.fill-lighten-4 {
  fill: #f8c1c3; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-lighten-4 {
  stroke: #f8c1c3; }

.materialize-red.lighten-3 {
  background-color: #f3989b !important; }

.materialize-red-text.text-lighten-3 {
  color: #f3989b !important; }

/* Fills for SVG */
.materialize-red-fill.fill-lighten-3 {
  fill: #f3989b; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-lighten-3 {
  stroke: #f3989b; }

.materialize-red.lighten-2 {
  background-color: #ee6e73 !important; }

.materialize-red-text.text-lighten-2 {
  color: #ee6e73 !important; }

/* Fills for SVG */
.materialize-red-fill.fill-lighten-2 {
  fill: #ee6e73; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-lighten-2 {
  stroke: #ee6e73; }

.materialize-red.lighten-1 {
  background-color: #ea454b !important; }

.materialize-red-text.text-lighten-1 {
  color: #ea454b !important; }

/* Fills for SVG */
.materialize-red-fill.fill-lighten-1 {
  fill: #ea454b; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-lighten-1 {
  stroke: #ea454b; }

.materialize-red.darken-1 {
  background-color: #d0181e !important; }

.materialize-red-text.text-darken-1 {
  color: #d0181e !important; }

/* Fills for SVG */
.materialize-red-fill.fill-darken-1 {
  fill: #d0181e; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-darken-1 {
  stroke: #d0181e; }

.materialize-red.darken-2 {
  background-color: #b9151b !important; }

.materialize-red-text.text-darken-2 {
  color: #b9151b !important; }

/* Fills for SVG */
.materialize-red-fill.fill-darken-2 {
  fill: #b9151b; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-darken-2 {
  stroke: #b9151b; }

.materialize-red.darken-3 {
  background-color: #a21318 !important; }

.materialize-red-text.text-darken-3 {
  color: #a21318 !important; }

/* Fills for SVG */
.materialize-red-fill.fill-darken-3 {
  fill: #a21318; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-darken-3 {
  stroke: #a21318; }

.materialize-red.darken-4 {
  background-color: #8b1014 !important; }

.materialize-red-text.text-darken-4 {
  color: #8b1014 !important; }

/* Fills for SVG */
.materialize-red-fill.fill-darken-4 {
  fill: #8b1014; }

/* Strokes for SVG */
.materialize-red-stroke.stroke-darken-4 {
  stroke: #8b1014; }

.red {
  background-color: #F44336 !important; }

.red-text {
  color: #F44336 !important; }

/* Fills for SVG */
.red-fill {
  fill: #F44336; }

/* Strokes for SVG */
.red-stroke {
  stroke: #F44336; }

.red.lighten-5 {
  background-color: #FFEBEE !important; }

.red-text.text-lighten-5 {
  color: #FFEBEE !important; }

/* Fills for SVG */
.red-fill.fill-lighten-5 {
  fill: #FFEBEE; }

/* Strokes for SVG */
.red-stroke.stroke-lighten-5 {
  stroke: #FFEBEE; }

.red.lighten-4 {
  background-color: #FFCDD2 !important; }

.red-text.text-lighten-4 {
  color: #FFCDD2 !important; }

/* Fills for SVG */
.red-fill.fill-lighten-4 {
  fill: #FFCDD2; }

/* Strokes for SVG */
.red-stroke.stroke-lighten-4 {
  stroke: #FFCDD2; }

.red.lighten-3 {
  background-color: #EF9A9A !important; }

.red-text.text-lighten-3 {
  color: #EF9A9A !important; }

/* Fills for SVG */
.red-fill.fill-lighten-3 {
  fill: #EF9A9A; }

/* Strokes for SVG */
.red-stroke.stroke-lighten-3 {
  stroke: #EF9A9A; }

.red.lighten-2 {
  background-color: #E57373 !important; }

.red-text.text-lighten-2 {
  color: #E57373 !important; }

/* Fills for SVG */
.red-fill.fill-lighten-2 {
  fill: #E57373; }

/* Strokes for SVG */
.red-stroke.stroke-lighten-2 {
  stroke: #E57373; }

.red.lighten-1 {
  background-color: #EF5350 !important; }

.red-text.text-lighten-1 {
  color: #EF5350 !important; }

/* Fills for SVG */
.red-fill.fill-lighten-1 {
  fill: #EF5350; }

/* Strokes for SVG */
.red-stroke.stroke-lighten-1 {
  stroke: #EF5350; }

.red.darken-1 {
  background-color: #E53935 !important; }

.red-text.text-darken-1 {
  color: #E53935 !important; }

/* Fills for SVG */
.red-fill.fill-darken-1 {
  fill: #E53935; }

/* Strokes for SVG */
.red-stroke.stroke-darken-1 {
  stroke: #E53935; }

.red.darken-2 {
  background-color: #D32F2F !important; }

.red-text.text-darken-2 {
  color: #D32F2F !important; }

/* Fills for SVG */
.red-fill.fill-darken-2 {
  fill: #D32F2F; }

/* Strokes for SVG */
.red-stroke.stroke-darken-2 {
  stroke: #D32F2F; }

.red.darken-3 {
  background-color: #C62828 !important; }

.red-text.text-darken-3 {
  color: #C62828 !important; }

/* Fills for SVG */
.red-fill.fill-darken-3 {
  fill: #C62828; }

/* Strokes for SVG */
.red-stroke.stroke-darken-3 {
  stroke: #C62828; }

.red.darken-4 {
  background-color: #B71C1C !important; }

.red-text.text-darken-4 {
  color: #B71C1C !important; }

/* Fills for SVG */
.red-fill.fill-darken-4 {
  fill: #B71C1C; }

/* Strokes for SVG */
.red-stroke.stroke-darken-4 {
  stroke: #B71C1C; }

.red.accent-1 {
  background-color: #FF8A80 !important; }

.red-text.text-accent-1 {
  color: #FF8A80 !important; }

/* Fills for SVG */
.red-fill.fill-accent-1 {
  fill: #FF8A80; }

/* Strokes for SVG */
.red-stroke.stroke-accent-1 {
  stroke: #FF8A80; }

.red.accent-2 {
  background-color: #FF5252 !important; }

.red-text.text-accent-2 {
  color: #FF5252 !important; }

/* Fills for SVG */
.red-fill.fill-accent-2 {
  fill: #FF5252; }

/* Strokes for SVG */
.red-stroke.stroke-accent-2 {
  stroke: #FF5252; }

.red.accent-3 {
  background-color: #FF1744 !important; }

.red-text.text-accent-3 {
  color: #FF1744 !important; }

/* Fills for SVG */
.red-fill.fill-accent-3 {
  fill: #FF1744; }

/* Strokes for SVG */
.red-stroke.stroke-accent-3 {
  stroke: #FF1744; }

.red.accent-4 {
  background-color: #D50000 !important; }

.red-text.text-accent-4 {
  color: #D50000 !important; }

/* Fills for SVG */
.red-fill.fill-accent-4 {
  fill: #D50000; }

/* Strokes for SVG */
.red-stroke.stroke-accent-4 {
  stroke: #D50000; }

.pink {
  background-color: #e91e63 !important; }

.pink-text {
  color: #e91e63 !important; }

/* Fills for SVG */
.pink-fill {
  fill: #e91e63; }

/* Strokes for SVG */
.pink-stroke {
  stroke: #e91e63; }

.pink.lighten-5 {
  background-color: #fce4ec !important; }

.pink-text.text-lighten-5 {
  color: #fce4ec !important; }

/* Fills for SVG */
.pink-fill.fill-lighten-5 {
  fill: #fce4ec; }

/* Strokes for SVG */
.pink-stroke.stroke-lighten-5 {
  stroke: #fce4ec; }

.pink.lighten-4 {
  background-color: #f8bbd0 !important; }

.pink-text.text-lighten-4 {
  color: #f8bbd0 !important; }

/* Fills for SVG */
.pink-fill.fill-lighten-4 {
  fill: #f8bbd0; }

/* Strokes for SVG */
.pink-stroke.stroke-lighten-4 {
  stroke: #f8bbd0; }

.pink.lighten-3 {
  background-color: #f48fb1 !important; }

.pink-text.text-lighten-3 {
  color: #f48fb1 !important; }

/* Fills for SVG */
.pink-fill.fill-lighten-3 {
  fill: #f48fb1; }

/* Strokes for SVG */
.pink-stroke.stroke-lighten-3 {
  stroke: #f48fb1; }

.pink.lighten-2 {
  background-color: #f06292 !important; }

.pink-text.text-lighten-2 {
  color: #f06292 !important; }

/* Fills for SVG */
.pink-fill.fill-lighten-2 {
  fill: #f06292; }

/* Strokes for SVG */
.pink-stroke.stroke-lighten-2 {
  stroke: #f06292; }

.pink.lighten-1 {
  background-color: #ec407a !important; }

.pink-text.text-lighten-1 {
  color: #ec407a !important; }

/* Fills for SVG */
.pink-fill.fill-lighten-1 {
  fill: #ec407a; }

/* Strokes for SVG */
.pink-stroke.stroke-lighten-1 {
  stroke: #ec407a; }

.pink.darken-1 {
  background-color: #d81b60 !important; }

.pink-text.text-darken-1 {
  color: #d81b60 !important; }

/* Fills for SVG */
.pink-fill.fill-darken-1 {
  fill: #d81b60; }

/* Strokes for SVG */
.pink-stroke.stroke-darken-1 {
  stroke: #d81b60; }

.pink.darken-2 {
  background-color: #c2185b !important; }

.pink-text.text-darken-2 {
  color: #c2185b !important; }

/* Fills for SVG */
.pink-fill.fill-darken-2 {
  fill: #c2185b; }

/* Strokes for SVG */
.pink-stroke.stroke-darken-2 {
  stroke: #c2185b; }

.pink.darken-3 {
  background-color: #ad1457 !important; }

.pink-text.text-darken-3 {
  color: #ad1457 !important; }

/* Fills for SVG */
.pink-fill.fill-darken-3 {
  fill: #ad1457; }

/* Strokes for SVG */
.pink-stroke.stroke-darken-3 {
  stroke: #ad1457; }

.pink.darken-4 {
  background-color: #880e4f !important; }

.pink-text.text-darken-4 {
  color: #880e4f !important; }

/* Fills for SVG */
.pink-fill.fill-darken-4 {
  fill: #880e4f; }

/* Strokes for SVG */
.pink-stroke.stroke-darken-4 {
  stroke: #880e4f; }

.pink.accent-1 {
  background-color: #ff80ab !important; }

.pink-text.text-accent-1 {
  color: #ff80ab !important; }

/* Fills for SVG */
.pink-fill.fill-accent-1 {
  fill: #ff80ab; }

/* Strokes for SVG */
.pink-stroke.stroke-accent-1 {
  stroke: #ff80ab; }

.pink.accent-2 {
  background-color: #ff4081 !important; }

.pink-text.text-accent-2 {
  color: #ff4081 !important; }

/* Fills for SVG */
.pink-fill.fill-accent-2 {
  fill: #ff4081; }

/* Strokes for SVG */
.pink-stroke.stroke-accent-2 {
  stroke: #ff4081; }

.pink.accent-3 {
  background-color: #f50057 !important; }

.pink-text.text-accent-3 {
  color: #f50057 !important; }

/* Fills for SVG */
.pink-fill.fill-accent-3 {
  fill: #f50057; }

/* Strokes for SVG */
.pink-stroke.stroke-accent-3 {
  stroke: #f50057; }

.pink.accent-4 {
  background-color: #c51162 !important; }

.pink-text.text-accent-4 {
  color: #c51162 !important; }

/* Fills for SVG */
.pink-fill.fill-accent-4 {
  fill: #c51162; }

/* Strokes for SVG */
.pink-stroke.stroke-accent-4 {
  stroke: #c51162; }

.purple {
  background-color: #9c27b0 !important; }

.purple-text {
  color: #9c27b0 !important; }

/* Fills for SVG */
.purple-fill {
  fill: #9c27b0; }

/* Strokes for SVG */
.purple-stroke {
  stroke: #9c27b0; }

.purple.lighten-5 {
  background-color: #f3e5f5 !important; }

.purple-text.text-lighten-5 {
  color: #f3e5f5 !important; }

/* Fills for SVG */
.purple-fill.fill-lighten-5 {
  fill: #f3e5f5; }

/* Strokes for SVG */
.purple-stroke.stroke-lighten-5 {
  stroke: #f3e5f5; }

.purple.lighten-4 {
  background-color: #e1bee7 !important; }

.purple-text.text-lighten-4 {
  color: #e1bee7 !important; }

/* Fills for SVG */
.purple-fill.fill-lighten-4 {
  fill: #e1bee7; }

/* Strokes for SVG */
.purple-stroke.stroke-lighten-4 {
  stroke: #e1bee7; }

.purple.lighten-3 {
  background-color: #ce93d8 !important; }

.purple-text.text-lighten-3 {
  color: #ce93d8 !important; }

/* Fills for SVG */
.purple-fill.fill-lighten-3 {
  fill: #ce93d8; }

/* Strokes for SVG */
.purple-stroke.stroke-lighten-3 {
  stroke: #ce93d8; }

.purple.lighten-2 {
  background-color: #ba68c8 !important; }

.purple-text.text-lighten-2 {
  color: #ba68c8 !important; }

/* Fills for SVG */
.purple-fill.fill-lighten-2 {
  fill: #ba68c8; }

/* Strokes for SVG */
.purple-stroke.stroke-lighten-2 {
  stroke: #ba68c8; }

.purple.lighten-1 {
  background-color: #ab47bc !important; }

.purple-text.text-lighten-1 {
  color: #ab47bc !important; }

/* Fills for SVG */
.purple-fill.fill-lighten-1 {
  fill: #ab47bc; }

/* Strokes for SVG */
.purple-stroke.stroke-lighten-1 {
  stroke: #ab47bc; }

.purple.darken-1 {
  background-color: #8e24aa !important; }

.purple-text.text-darken-1 {
  color: #8e24aa !important; }

/* Fills for SVG */
.purple-fill.fill-darken-1 {
  fill: #8e24aa; }

/* Strokes for SVG */
.purple-stroke.stroke-darken-1 {
  stroke: #8e24aa; }

.purple.darken-2 {
  background-color: #7b1fa2 !important; }

.purple-text.text-darken-2 {
  color: #7b1fa2 !important; }

/* Fills for SVG */
.purple-fill.fill-darken-2 {
  fill: #7b1fa2; }

/* Strokes for SVG */
.purple-stroke.stroke-darken-2 {
  stroke: #7b1fa2; }

.purple.darken-3 {
  background-color: #6a1b9a !important; }

.purple-text.text-darken-3 {
  color: #6a1b9a !important; }

/* Fills for SVG */
.purple-fill.fill-darken-3 {
  fill: #6a1b9a; }

/* Strokes for SVG */
.purple-stroke.stroke-darken-3 {
  stroke: #6a1b9a; }

.purple.darken-4 {
  background-color: #4a148c !important; }

.purple-text.text-darken-4 {
  color: #4a148c !important; }

/* Fills for SVG */
.purple-fill.fill-darken-4 {
  fill: #4a148c; }

/* Strokes for SVG */
.purple-stroke.stroke-darken-4 {
  stroke: #4a148c; }

.purple.accent-1 {
  background-color: #ea80fc !important; }

.purple-text.text-accent-1 {
  color: #ea80fc !important; }

/* Fills for SVG */
.purple-fill.fill-accent-1 {
  fill: #ea80fc; }

/* Strokes for SVG */
.purple-stroke.stroke-accent-1 {
  stroke: #ea80fc; }

.purple.accent-2 {
  background-color: #e040fb !important; }

.purple-text.text-accent-2 {
  color: #e040fb !important; }

/* Fills for SVG */
.purple-fill.fill-accent-2 {
  fill: #e040fb; }

/* Strokes for SVG */
.purple-stroke.stroke-accent-2 {
  stroke: #e040fb; }

.purple.accent-3 {
  background-color: #d500f9 !important; }

.purple-text.text-accent-3 {
  color: #d500f9 !important; }

/* Fills for SVG */
.purple-fill.fill-accent-3 {
  fill: #d500f9; }

/* Strokes for SVG */
.purple-stroke.stroke-accent-3 {
  stroke: #d500f9; }

.purple.accent-4 {
  background-color: #aa00ff !important; }

.purple-text.text-accent-4 {
  color: #aa00ff !important; }

/* Fills for SVG */
.purple-fill.fill-accent-4 {
  fill: #aa00ff; }

/* Strokes for SVG */
.purple-stroke.stroke-accent-4 {
  stroke: #aa00ff; }

.deep-purple {
  background-color: #673ab7 !important; }

.deep-purple-text {
  color: #673ab7 !important; }

/* Fills for SVG */
.deep-purple-fill {
  fill: #673ab7; }

/* Strokes for SVG */
.deep-purple-stroke {
  stroke: #673ab7; }

.deep-purple.lighten-5 {
  background-color: #ede7f6 !important; }

.deep-purple-text.text-lighten-5 {
  color: #ede7f6 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-lighten-5 {
  fill: #ede7f6; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-lighten-5 {
  stroke: #ede7f6; }

.deep-purple.lighten-4 {
  background-color: #d1c4e9 !important; }

.deep-purple-text.text-lighten-4 {
  color: #d1c4e9 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-lighten-4 {
  fill: #d1c4e9; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-lighten-4 {
  stroke: #d1c4e9; }

.deep-purple.lighten-3 {
  background-color: #b39ddb !important; }

.deep-purple-text.text-lighten-3 {
  color: #b39ddb !important; }

/* Fills for SVG */
.deep-purple-fill.fill-lighten-3 {
  fill: #b39ddb; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-lighten-3 {
  stroke: #b39ddb; }

.deep-purple.lighten-2 {
  background-color: #9575cd !important; }

.deep-purple-text.text-lighten-2 {
  color: #9575cd !important; }

/* Fills for SVG */
.deep-purple-fill.fill-lighten-2 {
  fill: #9575cd; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-lighten-2 {
  stroke: #9575cd; }

.deep-purple.lighten-1 {
  background-color: #7e57c2 !important; }

.deep-purple-text.text-lighten-1 {
  color: #7e57c2 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-lighten-1 {
  fill: #7e57c2; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-lighten-1 {
  stroke: #7e57c2; }

.deep-purple.darken-1 {
  background-color: #5e35b1 !important; }

.deep-purple-text.text-darken-1 {
  color: #5e35b1 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-darken-1 {
  fill: #5e35b1; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-darken-1 {
  stroke: #5e35b1; }

.deep-purple.darken-2 {
  background-color: #512da8 !important; }

.deep-purple-text.text-darken-2 {
  color: #512da8 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-darken-2 {
  fill: #512da8; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-darken-2 {
  stroke: #512da8; }

.deep-purple.darken-3 {
  background-color: #4527a0 !important; }

.deep-purple-text.text-darken-3 {
  color: #4527a0 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-darken-3 {
  fill: #4527a0; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-darken-3 {
  stroke: #4527a0; }

.deep-purple.darken-4 {
  background-color: #311b92 !important; }

.deep-purple-text.text-darken-4 {
  color: #311b92 !important; }

/* Fills for SVG */
.deep-purple-fill.fill-darken-4 {
  fill: #311b92; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-darken-4 {
  stroke: #311b92; }

.deep-purple.accent-1 {
  background-color: #b388ff !important; }

.deep-purple-text.text-accent-1 {
  color: #b388ff !important; }

/* Fills for SVG */
.deep-purple-fill.fill-accent-1 {
  fill: #b388ff; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-accent-1 {
  stroke: #b388ff; }

.deep-purple.accent-2 {
  background-color: #7c4dff !important; }

.deep-purple-text.text-accent-2 {
  color: #7c4dff !important; }

/* Fills for SVG */
.deep-purple-fill.fill-accent-2 {
  fill: #7c4dff; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-accent-2 {
  stroke: #7c4dff; }

.deep-purple.accent-3 {
  background-color: #651fff !important; }

.deep-purple-text.text-accent-3 {
  color: #651fff !important; }

/* Fills for SVG */
.deep-purple-fill.fill-accent-3 {
  fill: #651fff; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-accent-3 {
  stroke: #651fff; }

.deep-purple.accent-4 {
  background-color: #6200ea !important; }

.deep-purple-text.text-accent-4 {
  color: #6200ea !important; }

/* Fills for SVG */
.deep-purple-fill.fill-accent-4 {
  fill: #6200ea; }

/* Strokes for SVG */
.deep-purple-stroke.stroke-accent-4 {
  stroke: #6200ea; }

.indigo {
  background-color: #3f51b5 !important; }

.indigo-text {
  color: #3f51b5 !important; }

/* Fills for SVG */
.indigo-fill {
  fill: #3f51b5; }

/* Strokes for SVG */
.indigo-stroke {
  stroke: #3f51b5; }

.indigo.lighten-5 {
  background-color: #e8eaf6 !important; }

.indigo-text.text-lighten-5 {
  color: #e8eaf6 !important; }

/* Fills for SVG */
.indigo-fill.fill-lighten-5 {
  fill: #e8eaf6; }

/* Strokes for SVG */
.indigo-stroke.stroke-lighten-5 {
  stroke: #e8eaf6; }

.indigo.lighten-4 {
  background-color: #c5cae9 !important; }

.indigo-text.text-lighten-4 {
  color: #c5cae9 !important; }

/* Fills for SVG */
.indigo-fill.fill-lighten-4 {
  fill: #c5cae9; }

/* Strokes for SVG */
.indigo-stroke.stroke-lighten-4 {
  stroke: #c5cae9; }

.indigo.lighten-3 {
  background-color: #9fa8da !important; }

.indigo-text.text-lighten-3 {
  color: #9fa8da !important; }

/* Fills for SVG */
.indigo-fill.fill-lighten-3 {
  fill: #9fa8da; }

/* Strokes for SVG */
.indigo-stroke.stroke-lighten-3 {
  stroke: #9fa8da; }

.indigo.lighten-2 {
  background-color: #7986cb !important; }

.indigo-text.text-lighten-2 {
  color: #7986cb !important; }

/* Fills for SVG */
.indigo-fill.fill-lighten-2 {
  fill: #7986cb; }

/* Strokes for SVG */
.indigo-stroke.stroke-lighten-2 {
  stroke: #7986cb; }

.indigo.lighten-1 {
  background-color: #5c6bc0 !important; }

.indigo-text.text-lighten-1 {
  color: #5c6bc0 !important; }

/* Fills for SVG */
.indigo-fill.fill-lighten-1 {
  fill: #5c6bc0; }

/* Strokes for SVG */
.indigo-stroke.stroke-lighten-1 {
  stroke: #5c6bc0; }

.indigo.darken-1 {
  background-color: #3949ab !important; }

.indigo-text.text-darken-1 {
  color: #3949ab !important; }

/* Fills for SVG */
.indigo-fill.fill-darken-1 {
  fill: #3949ab; }

/* Strokes for SVG */
.indigo-stroke.stroke-darken-1 {
  stroke: #3949ab; }

.indigo.darken-2 {
  background-color: #303f9f !important; }

.indigo-text.text-darken-2 {
  color: #303f9f !important; }

/* Fills for SVG */
.indigo-fill.fill-darken-2 {
  fill: #303f9f; }

/* Strokes for SVG */
.indigo-stroke.stroke-darken-2 {
  stroke: #303f9f; }

.indigo.darken-3 {
  background-color: #283593 !important; }

.indigo-text.text-darken-3 {
  color: #283593 !important; }

/* Fills for SVG */
.indigo-fill.fill-darken-3 {
  fill: #283593; }

/* Strokes for SVG */
.indigo-stroke.stroke-darken-3 {
  stroke: #283593; }

.indigo.darken-4 {
  background-color: #1a237e !important; }

.indigo-text.text-darken-4 {
  color: #1a237e !important; }

/* Fills for SVG */
.indigo-fill.fill-darken-4 {
  fill: #1a237e; }

/* Strokes for SVG */
.indigo-stroke.stroke-darken-4 {
  stroke: #1a237e; }

.indigo.accent-1 {
  background-color: #8c9eff !important; }

.indigo-text.text-accent-1 {
  color: #8c9eff !important; }

/* Fills for SVG */
.indigo-fill.fill-accent-1 {
  fill: #8c9eff; }

/* Strokes for SVG */
.indigo-stroke.stroke-accent-1 {
  stroke: #8c9eff; }

.indigo.accent-2 {
  background-color: #536dfe !important; }

.indigo-text.text-accent-2 {
  color: #536dfe !important; }

/* Fills for SVG */
.indigo-fill.fill-accent-2 {
  fill: #536dfe; }

/* Strokes for SVG */
.indigo-stroke.stroke-accent-2 {
  stroke: #536dfe; }

.indigo.accent-3 {
  background-color: #3d5afe !important; }

.indigo-text.text-accent-3 {
  color: #3d5afe !important; }

/* Fills for SVG */
.indigo-fill.fill-accent-3 {
  fill: #3d5afe; }

/* Strokes for SVG */
.indigo-stroke.stroke-accent-3 {
  stroke: #3d5afe; }

.indigo.accent-4 {
  background-color: #304ffe !important; }

.indigo-text.text-accent-4 {
  color: #304ffe !important; }

/* Fills for SVG */
.indigo-fill.fill-accent-4 {
  fill: #304ffe; }

/* Strokes for SVG */
.indigo-stroke.stroke-accent-4 {
  stroke: #304ffe; }

.blue {
  background-color: #2196F3 !important; }

.blue-text {
  color: #2196F3 !important; }

/* Fills for SVG */
.blue-fill {
  fill: #2196F3; }

/* Strokes for SVG */
.blue-stroke {
  stroke: #2196F3; }

.blue.lighten-5 {
  background-color: #E3F2FD !important; }

.blue-text.text-lighten-5 {
  color: #E3F2FD !important; }

/* Fills for SVG */
.blue-fill.fill-lighten-5 {
  fill: #E3F2FD; }

/* Strokes for SVG */
.blue-stroke.stroke-lighten-5 {
  stroke: #E3F2FD; }

.blue.lighten-4 {
  background-color: #BBDEFB !important; }

.blue-text.text-lighten-4 {
  color: #BBDEFB !important; }

/* Fills for SVG */
.blue-fill.fill-lighten-4 {
  fill: #BBDEFB; }

/* Strokes for SVG */
.blue-stroke.stroke-lighten-4 {
  stroke: #BBDEFB; }

.blue.lighten-3 {
  background-color: #90CAF9 !important; }

.blue-text.text-lighten-3 {
  color: #90CAF9 !important; }

/* Fills for SVG */
.blue-fill.fill-lighten-3 {
  fill: #90CAF9; }

/* Strokes for SVG */
.blue-stroke.stroke-lighten-3 {
  stroke: #90CAF9; }

.blue.lighten-2 {
  background-color: #64B5F6 !important; }

.blue-text.text-lighten-2 {
  color: #64B5F6 !important; }

/* Fills for SVG */
.blue-fill.fill-lighten-2 {
  fill: #64B5F6; }

/* Strokes for SVG */
.blue-stroke.stroke-lighten-2 {
  stroke: #64B5F6; }

.blue.lighten-1 {
  background-color: #42A5F5 !important; }

.blue-text.text-lighten-1 {
  color: #42A5F5 !important; }

/* Fills for SVG */
.blue-fill.fill-lighten-1 {
  fill: #42A5F5; }

/* Strokes for SVG */
.blue-stroke.stroke-lighten-1 {
  stroke: #42A5F5; }

.blue.darken-1 {
  background-color: #1E88E5 !important; }

.blue-text.text-darken-1 {
  color: #1E88E5 !important; }

/* Fills for SVG */
.blue-fill.fill-darken-1 {
  fill: #1E88E5; }

/* Strokes for SVG */
.blue-stroke.stroke-darken-1 {
  stroke: #1E88E5; }

.blue.darken-2 {
  background-color: #1976D2 !important; }

.blue-text.text-darken-2 {
  color: #1976D2 !important; }

/* Fills for SVG */
.blue-fill.fill-darken-2 {
  fill: #1976D2; }

/* Strokes for SVG */
.blue-stroke.stroke-darken-2 {
  stroke: #1976D2; }

.blue.darken-3 {
  background-color: #1565C0 !important; }

.blue-text.text-darken-3 {
  color: #1565C0 !important; }

/* Fills for SVG */
.blue-fill.fill-darken-3 {
  fill: #1565C0; }

/* Strokes for SVG */
.blue-stroke.stroke-darken-3 {
  stroke: #1565C0; }

.blue.darken-4 {
  background-color: #0D47A1 !important; }

.blue-text.text-darken-4 {
  color: #0D47A1 !important; }

/* Fills for SVG */
.blue-fill.fill-darken-4 {
  fill: #0D47A1; }

/* Strokes for SVG */
.blue-stroke.stroke-darken-4 {
  stroke: #0D47A1; }

.blue.accent-1 {
  background-color: #82B1FF !important; }

.blue-text.text-accent-1 {
  color: #82B1FF !important; }

/* Fills for SVG */
.blue-fill.fill-accent-1 {
  fill: #82B1FF; }

/* Strokes for SVG */
.blue-stroke.stroke-accent-1 {
  stroke: #82B1FF; }

.blue.accent-2 {
  background-color: #448AFF !important; }

.blue-text.text-accent-2 {
  color: #448AFF !important; }

/* Fills for SVG */
.blue-fill.fill-accent-2 {
  fill: #448AFF; }

/* Strokes for SVG */
.blue-stroke.stroke-accent-2 {
  stroke: #448AFF; }

.blue.accent-3 {
  background-color: #2979FF !important; }

.blue-text.text-accent-3 {
  color: #2979FF !important; }

/* Fills for SVG */
.blue-fill.fill-accent-3 {
  fill: #2979FF; }

/* Strokes for SVG */
.blue-stroke.stroke-accent-3 {
  stroke: #2979FF; }

.blue.accent-4 {
  background-color: #2962FF !important; }

.blue-text.text-accent-4 {
  color: #2962FF !important; }

/* Fills for SVG */
.blue-fill.fill-accent-4 {
  fill: #2962FF; }

/* Strokes for SVG */
.blue-stroke.stroke-accent-4 {
  stroke: #2962FF; }

.light-blue {
  background-color: #03a9f4 !important; }

.light-blue-text {
  color: #03a9f4 !important; }

/* Fills for SVG */
.light-blue-fill {
  fill: #03a9f4; }

/* Strokes for SVG */
.light-blue-stroke {
  stroke: #03a9f4; }

.light-blue.lighten-5 {
  background-color: #e1f5fe !important; }

.light-blue-text.text-lighten-5 {
  color: #e1f5fe !important; }

/* Fills for SVG */
.light-blue-fill.fill-lighten-5 {
  fill: #e1f5fe; }

/* Strokes for SVG */
.light-blue-stroke.stroke-lighten-5 {
  stroke: #e1f5fe; }

.light-blue.lighten-4 {
  background-color: #b3e5fc !important; }

.light-blue-text.text-lighten-4 {
  color: #b3e5fc !important; }

/* Fills for SVG */
.light-blue-fill.fill-lighten-4 {
  fill: #b3e5fc; }

/* Strokes for SVG */
.light-blue-stroke.stroke-lighten-4 {
  stroke: #b3e5fc; }

.light-blue.lighten-3 {
  background-color: #81d4fa !important; }

.light-blue-text.text-lighten-3 {
  color: #81d4fa !important; }

/* Fills for SVG */
.light-blue-fill.fill-lighten-3 {
  fill: #81d4fa; }

/* Strokes for SVG */
.light-blue-stroke.stroke-lighten-3 {
  stroke: #81d4fa; }

.light-blue.lighten-2 {
  background-color: #4fc3f7 !important; }

.light-blue-text.text-lighten-2 {
  color: #4fc3f7 !important; }

/* Fills for SVG */
.light-blue-fill.fill-lighten-2 {
  fill: #4fc3f7; }

/* Strokes for SVG */
.light-blue-stroke.stroke-lighten-2 {
  stroke: #4fc3f7; }

.light-blue.lighten-1 {
  background-color: #29b6f6 !important; }

.light-blue-text.text-lighten-1 {
  color: #29b6f6 !important; }

/* Fills for SVG */
.light-blue-fill.fill-lighten-1 {
  fill: #29b6f6; }

/* Strokes for SVG */
.light-blue-stroke.stroke-lighten-1 {
  stroke: #29b6f6; }

.light-blue.darken-1 {
  background-color: #039be5 !important; }

.light-blue-text.text-darken-1 {
  color: #039be5 !important; }

/* Fills for SVG */
.light-blue-fill.fill-darken-1 {
  fill: #039be5; }

/* Strokes for SVG */
.light-blue-stroke.stroke-darken-1 {
  stroke: #039be5; }

.light-blue.darken-2 {
  background-color: #0288d1 !important; }

.light-blue-text.text-darken-2 {
  color: #0288d1 !important; }

/* Fills for SVG */
.light-blue-fill.fill-darken-2 {
  fill: #0288d1; }

/* Strokes for SVG */
.light-blue-stroke.stroke-darken-2 {
  stroke: #0288d1; }

.light-blue.darken-3 {
  background-color: #0277bd !important; }

.light-blue-text.text-darken-3 {
  color: #0277bd !important; }

/* Fills for SVG */
.light-blue-fill.fill-darken-3 {
  fill: #0277bd; }

/* Strokes for SVG */
.light-blue-stroke.stroke-darken-3 {
  stroke: #0277bd; }

.light-blue.darken-4 {
  background-color: #01579b !important; }

.light-blue-text.text-darken-4 {
  color: #01579b !important; }

/* Fills for SVG */
.light-blue-fill.fill-darken-4 {
  fill: #01579b; }

/* Strokes for SVG */
.light-blue-stroke.stroke-darken-4 {
  stroke: #01579b; }

.light-blue.accent-1 {
  background-color: #80d8ff !important; }

.light-blue-text.text-accent-1 {
  color: #80d8ff !important; }

/* Fills for SVG */
.light-blue-fill.fill-accent-1 {
  fill: #80d8ff; }

/* Strokes for SVG */
.light-blue-stroke.stroke-accent-1 {
  stroke: #80d8ff; }

.light-blue.accent-2 {
  background-color: #40c4ff !important; }

.light-blue-text.text-accent-2 {
  color: #40c4ff !important; }

/* Fills for SVG */
.light-blue-fill.fill-accent-2 {
  fill: #40c4ff; }

/* Strokes for SVG */
.light-blue-stroke.stroke-accent-2 {
  stroke: #40c4ff; }

.light-blue.accent-3 {
  background-color: #00b0ff !important; }

.light-blue-text.text-accent-3 {
  color: #00b0ff !important; }

/* Fills for SVG */
.light-blue-fill.fill-accent-3 {
  fill: #00b0ff; }

/* Strokes for SVG */
.light-blue-stroke.stroke-accent-3 {
  stroke: #00b0ff; }

.light-blue.accent-4 {
  background-color: #0091ea !important; }

.light-blue-text.text-accent-4 {
  color: #0091ea !important; }

/* Fills for SVG */
.light-blue-fill.fill-accent-4 {
  fill: #0091ea; }

/* Strokes for SVG */
.light-blue-stroke.stroke-accent-4 {
  stroke: #0091ea; }

.cyan {
  background-color: #00bcd4 !important; }

.cyan-text {
  color: #00bcd4 !important; }

/* Fills for SVG */
.cyan-fill {
  fill: #00bcd4; }

/* Strokes for SVG */
.cyan-stroke {
  stroke: #00bcd4; }

.cyan.lighten-5 {
  background-color: #e0f7fa !important; }

.cyan-text.text-lighten-5 {
  color: #e0f7fa !important; }

/* Fills for SVG */
.cyan-fill.fill-lighten-5 {
  fill: #e0f7fa; }

/* Strokes for SVG */
.cyan-stroke.stroke-lighten-5 {
  stroke: #e0f7fa; }

.cyan.lighten-4 {
  background-color: #b2ebf2 !important; }

.cyan-text.text-lighten-4 {
  color: #b2ebf2 !important; }

/* Fills for SVG */
.cyan-fill.fill-lighten-4 {
  fill: #b2ebf2; }

/* Strokes for SVG */
.cyan-stroke.stroke-lighten-4 {
  stroke: #b2ebf2; }

.cyan.lighten-3 {
  background-color: #80deea !important; }

.cyan-text.text-lighten-3 {
  color: #80deea !important; }

/* Fills for SVG */
.cyan-fill.fill-lighten-3 {
  fill: #80deea; }

/* Strokes for SVG */
.cyan-stroke.stroke-lighten-3 {
  stroke: #80deea; }

.cyan.lighten-2 {
  background-color: #4dd0e1 !important; }

.cyan-text.text-lighten-2 {
  color: #4dd0e1 !important; }

/* Fills for SVG */
.cyan-fill.fill-lighten-2 {
  fill: #4dd0e1; }

/* Strokes for SVG */
.cyan-stroke.stroke-lighten-2 {
  stroke: #4dd0e1; }

.cyan.lighten-1 {
  background-color: #26c6da !important; }

.cyan-text.text-lighten-1 {
  color: #26c6da !important; }

/* Fills for SVG */
.cyan-fill.fill-lighten-1 {
  fill: #26c6da; }

/* Strokes for SVG */
.cyan-stroke.stroke-lighten-1 {
  stroke: #26c6da; }

.cyan.darken-1 {
  background-color: #00acc1 !important; }

.cyan-text.text-darken-1 {
  color: #00acc1 !important; }

/* Fills for SVG */
.cyan-fill.fill-darken-1 {
  fill: #00acc1; }

/* Strokes for SVG */
.cyan-stroke.stroke-darken-1 {
  stroke: #00acc1; }

.cyan.darken-2 {
  background-color: #0097a7 !important; }

.cyan-text.text-darken-2 {
  color: #0097a7 !important; }

/* Fills for SVG */
.cyan-fill.fill-darken-2 {
  fill: #0097a7; }

/* Strokes for SVG */
.cyan-stroke.stroke-darken-2 {
  stroke: #0097a7; }

.cyan.darken-3 {
  background-color: #00838f !important; }

.cyan-text.text-darken-3 {
  color: #00838f !important; }

/* Fills for SVG */
.cyan-fill.fill-darken-3 {
  fill: #00838f; }

/* Strokes for SVG */
.cyan-stroke.stroke-darken-3 {
  stroke: #00838f; }

.cyan.darken-4 {
  background-color: #006064 !important; }

.cyan-text.text-darken-4 {
  color: #006064 !important; }

/* Fills for SVG */
.cyan-fill.fill-darken-4 {
  fill: #006064; }

/* Strokes for SVG */
.cyan-stroke.stroke-darken-4 {
  stroke: #006064; }

.cyan.accent-1 {
  background-color: #84ffff !important; }

.cyan-text.text-accent-1 {
  color: #84ffff !important; }

/* Fills for SVG */
.cyan-fill.fill-accent-1 {
  fill: #84ffff; }

/* Strokes for SVG */
.cyan-stroke.stroke-accent-1 {
  stroke: #84ffff; }

.cyan.accent-2 {
  background-color: #18ffff !important; }

.cyan-text.text-accent-2 {
  color: #18ffff !important; }

/* Fills for SVG */
.cyan-fill.fill-accent-2 {
  fill: #18ffff; }

/* Strokes for SVG */
.cyan-stroke.stroke-accent-2 {
  stroke: #18ffff; }

.cyan.accent-3 {
  background-color: #00e5ff !important; }

.cyan-text.text-accent-3 {
  color: #00e5ff !important; }

/* Fills for SVG */
.cyan-fill.fill-accent-3 {
  fill: #00e5ff; }

/* Strokes for SVG */
.cyan-stroke.stroke-accent-3 {
  stroke: #00e5ff; }

.cyan.accent-4 {
  background-color: #00b8d4 !important; }

.cyan-text.text-accent-4 {
  color: #00b8d4 !important; }

/* Fills for SVG */
.cyan-fill.fill-accent-4 {
  fill: #00b8d4; }

/* Strokes for SVG */
.cyan-stroke.stroke-accent-4 {
  stroke: #00b8d4; }

.teal {
  background-color: #009688 !important; }

.teal-text {
  color: #009688 !important; }

/* Fills for SVG */
.teal-fill {
  fill: #009688; }

/* Strokes for SVG */
.teal-stroke {
  stroke: #009688; }

.teal.lighten-5 {
  background-color: #e0f2f1 !important; }

.teal-text.text-lighten-5 {
  color: #e0f2f1 !important; }

/* Fills for SVG */
.teal-fill.fill-lighten-5 {
  fill: #e0f2f1; }

/* Strokes for SVG */
.teal-stroke.stroke-lighten-5 {
  stroke: #e0f2f1; }

.teal.lighten-4 {
  background-color: #b2dfdb !important; }

.teal-text.text-lighten-4 {
  color: #b2dfdb !important; }

/* Fills for SVG */
.teal-fill.fill-lighten-4 {
  fill: #b2dfdb; }

/* Strokes for SVG */
.teal-stroke.stroke-lighten-4 {
  stroke: #b2dfdb; }

.teal.lighten-3 {
  background-color: #80cbc4 !important; }

.teal-text.text-lighten-3 {
  color: #80cbc4 !important; }

/* Fills for SVG */
.teal-fill.fill-lighten-3 {
  fill: #80cbc4; }

/* Strokes for SVG */
.teal-stroke.stroke-lighten-3 {
  stroke: #80cbc4; }

.teal.lighten-2 {
  background-color: #4db6ac !important; }

.teal-text.text-lighten-2 {
  color: #4db6ac !important; }

/* Fills for SVG */
.teal-fill.fill-lighten-2 {
  fill: #4db6ac; }

/* Strokes for SVG */
.teal-stroke.stroke-lighten-2 {
  stroke: #4db6ac; }

.teal.lighten-1 {
  background-color: #26a69a !important; }

.teal-text.text-lighten-1 {
  color: #26a69a !important; }

/* Fills for SVG */
.teal-fill.fill-lighten-1 {
  fill: #26a69a; }

/* Strokes for SVG */
.teal-stroke.stroke-lighten-1 {
  stroke: #26a69a; }

.teal.darken-1 {
  background-color: #00897b !important; }

.teal-text.text-darken-1 {
  color: #00897b !important; }

/* Fills for SVG */
.teal-fill.fill-darken-1 {
  fill: #00897b; }

/* Strokes for SVG */
.teal-stroke.stroke-darken-1 {
  stroke: #00897b; }

.teal.darken-2 {
  background-color: #00796b !important; }

.teal-text.text-darken-2 {
  color: #00796b !important; }

/* Fills for SVG */
.teal-fill.fill-darken-2 {
  fill: #00796b; }

/* Strokes for SVG */
.teal-stroke.stroke-darken-2 {
  stroke: #00796b; }

.teal.darken-3 {
  background-color: #00695c !important; }

.teal-text.text-darken-3 {
  color: #00695c !important; }

/* Fills for SVG */
.teal-fill.fill-darken-3 {
  fill: #00695c; }

/* Strokes for SVG */
.teal-stroke.stroke-darken-3 {
  stroke: #00695c; }

.teal.darken-4 {
  background-color: #004d40 !important; }

.teal-text.text-darken-4 {
  color: #004d40 !important; }

/* Fills for SVG */
.teal-fill.fill-darken-4 {
  fill: #004d40; }

/* Strokes for SVG */
.teal-stroke.stroke-darken-4 {
  stroke: #004d40; }

.teal.accent-1 {
  background-color: #a7ffeb !important; }

.teal-text.text-accent-1 {
  color: #a7ffeb !important; }

/* Fills for SVG */
.teal-fill.fill-accent-1 {
  fill: #a7ffeb; }

/* Strokes for SVG */
.teal-stroke.stroke-accent-1 {
  stroke: #a7ffeb; }

.teal.accent-2 {
  background-color: #64ffda !important; }

.teal-text.text-accent-2 {
  color: #64ffda !important; }

/* Fills for SVG */
.teal-fill.fill-accent-2 {
  fill: #64ffda; }

/* Strokes for SVG */
.teal-stroke.stroke-accent-2 {
  stroke: #64ffda; }

.teal.accent-3 {
  background-color: #1de9b6 !important; }

.teal-text.text-accent-3 {
  color: #1de9b6 !important; }

/* Fills for SVG */
.teal-fill.fill-accent-3 {
  fill: #1de9b6; }

/* Strokes for SVG */
.teal-stroke.stroke-accent-3 {
  stroke: #1de9b6; }

.teal.accent-4 {
  background-color: #00bfa5 !important; }

.teal-text.text-accent-4 {
  color: #00bfa5 !important; }

/* Fills for SVG */
.teal-fill.fill-accent-4 {
  fill: #00bfa5; }

/* Strokes for SVG */
.teal-stroke.stroke-accent-4 {
  stroke: #00bfa5; }

.green {
  background-color: #4CAF50 !important; }

.green-text {
  color: #4CAF50 !important; }

/* Fills for SVG */
.green-fill {
  fill: #4CAF50; }

/* Strokes for SVG */
.green-stroke {
  stroke: #4CAF50; }

.green.lighten-5 {
  background-color: #E8F5E9 !important; }

.green-text.text-lighten-5 {
  color: #E8F5E9 !important; }

/* Fills for SVG */
.green-fill.fill-lighten-5 {
  fill: #E8F5E9; }

/* Strokes for SVG */
.green-stroke.stroke-lighten-5 {
  stroke: #E8F5E9; }

.green.lighten-4 {
  background-color: #C8E6C9 !important; }

.green-text.text-lighten-4 {
  color: #C8E6C9 !important; }

/* Fills for SVG */
.green-fill.fill-lighten-4 {
  fill: #C8E6C9; }

/* Strokes for SVG */
.green-stroke.stroke-lighten-4 {
  stroke: #C8E6C9; }

.green.lighten-3 {
  background-color: #A5D6A7 !important; }

.green-text.text-lighten-3 {
  color: #A5D6A7 !important; }

/* Fills for SVG */
.green-fill.fill-lighten-3 {
  fill: #A5D6A7; }

/* Strokes for SVG */
.green-stroke.stroke-lighten-3 {
  stroke: #A5D6A7; }

.green.lighten-2 {
  background-color: #81C784 !important; }

.green-text.text-lighten-2 {
  color: #81C784 !important; }

/* Fills for SVG */
.green-fill.fill-lighten-2 {
  fill: #81C784; }

/* Strokes for SVG */
.green-stroke.stroke-lighten-2 {
  stroke: #81C784; }

.green.lighten-1 {
  background-color: #66BB6A !important; }

.green-text.text-lighten-1 {
  color: #66BB6A !important; }

/* Fills for SVG */
.green-fill.fill-lighten-1 {
  fill: #66BB6A; }

/* Strokes for SVG */
.green-stroke.stroke-lighten-1 {
  stroke: #66BB6A; }

.green.darken-1 {
  background-color: #43A047 !important; }

.green-text.text-darken-1 {
  color: #43A047 !important; }

/* Fills for SVG */
.green-fill.fill-darken-1 {
  fill: #43A047; }

/* Strokes for SVG */
.green-stroke.stroke-darken-1 {
  stroke: #43A047; }

.green.darken-2 {
  background-color: #388E3C !important; }

.green-text.text-darken-2 {
  color: #388E3C !important; }

/* Fills for SVG */
.green-fill.fill-darken-2 {
  fill: #388E3C; }

/* Strokes for SVG */
.green-stroke.stroke-darken-2 {
  stroke: #388E3C; }

.green.darken-3 {
  background-color: #2E7D32 !important; }

.green-text.text-darken-3 {
  color: #2E7D32 !important; }

/* Fills for SVG */
.green-fill.fill-darken-3 {
  fill: #2E7D32; }

/* Strokes for SVG */
.green-stroke.stroke-darken-3 {
  stroke: #2E7D32; }

.green.darken-4 {
  background-color: #1B5E20 !important; }

.green-text.text-darken-4 {
  color: #1B5E20 !important; }

/* Fills for SVG */
.green-fill.fill-darken-4 {
  fill: #1B5E20; }

/* Strokes for SVG */
.green-stroke.stroke-darken-4 {
  stroke: #1B5E20; }

.green.accent-1 {
  background-color: #B9F6CA !important; }

.green-text.text-accent-1 {
  color: #B9F6CA !important; }

/* Fills for SVG */
.green-fill.fill-accent-1 {
  fill: #B9F6CA; }

/* Strokes for SVG */
.green-stroke.stroke-accent-1 {
  stroke: #B9F6CA; }

.green.accent-2 {
  background-color: #69F0AE !important; }

.green-text.text-accent-2 {
  color: #69F0AE !important; }

/* Fills for SVG */
.green-fill.fill-accent-2 {
  fill: #69F0AE; }

/* Strokes for SVG */
.green-stroke.stroke-accent-2 {
  stroke: #69F0AE; }

.green.accent-3 {
  background-color: #00E676 !important; }

.green-text.text-accent-3 {
  color: #00E676 !important; }

/* Fills for SVG */
.green-fill.fill-accent-3 {
  fill: #00E676; }

/* Strokes for SVG */
.green-stroke.stroke-accent-3 {
  stroke: #00E676; }

.green.accent-4 {
  background-color: #00C853 !important; }

.green-text.text-accent-4 {
  color: #00C853 !important; }

/* Fills for SVG */
.green-fill.fill-accent-4 {
  fill: #00C853; }

/* Strokes for SVG */
.green-stroke.stroke-accent-4 {
  stroke: #00C853; }

.light-green {
  background-color: #8bc34a !important; }

.light-green-text {
  color: #8bc34a !important; }

/* Fills for SVG */
.light-green-fill {
  fill: #8bc34a; }

/* Strokes for SVG */
.light-green-stroke {
  stroke: #8bc34a; }

.light-green.lighten-5 {
  background-color: #f1f8e9 !important; }

.light-green-text.text-lighten-5 {
  color: #f1f8e9 !important; }

/* Fills for SVG */
.light-green-fill.fill-lighten-5 {
  fill: #f1f8e9; }

/* Strokes for SVG */
.light-green-stroke.stroke-lighten-5 {
  stroke: #f1f8e9; }

.light-green.lighten-4 {
  background-color: #dcedc8 !important; }

.light-green-text.text-lighten-4 {
  color: #dcedc8 !important; }

/* Fills for SVG */
.light-green-fill.fill-lighten-4 {
  fill: #dcedc8; }

/* Strokes for SVG */
.light-green-stroke.stroke-lighten-4 {
  stroke: #dcedc8; }

.light-green.lighten-3 {
  background-color: #c5e1a5 !important; }

.light-green-text.text-lighten-3 {
  color: #c5e1a5 !important; }

/* Fills for SVG */
.light-green-fill.fill-lighten-3 {
  fill: #c5e1a5; }

/* Strokes for SVG */
.light-green-stroke.stroke-lighten-3 {
  stroke: #c5e1a5; }

.light-green.lighten-2 {
  background-color: #aed581 !important; }

.light-green-text.text-lighten-2 {
  color: #aed581 !important; }

/* Fills for SVG */
.light-green-fill.fill-lighten-2 {
  fill: #aed581; }

/* Strokes for SVG */
.light-green-stroke.stroke-lighten-2 {
  stroke: #aed581; }

.light-green.lighten-1 {
  background-color: #9ccc65 !important; }

.light-green-text.text-lighten-1 {
  color: #9ccc65 !important; }

/* Fills for SVG */
.light-green-fill.fill-lighten-1 {
  fill: #9ccc65; }

/* Strokes for SVG */
.light-green-stroke.stroke-lighten-1 {
  stroke: #9ccc65; }

.light-green.darken-1 {
  background-color: #7cb342 !important; }

.light-green-text.text-darken-1 {
  color: #7cb342 !important; }

/* Fills for SVG */
.light-green-fill.fill-darken-1 {
  fill: #7cb342; }

/* Strokes for SVG */
.light-green-stroke.stroke-darken-1 {
  stroke: #7cb342; }

.light-green.darken-2 {
  background-color: #689f38 !important; }

.light-green-text.text-darken-2 {
  color: #689f38 !important; }

/* Fills for SVG */
.light-green-fill.fill-darken-2 {
  fill: #689f38; }

/* Strokes for SVG */
.light-green-stroke.stroke-darken-2 {
  stroke: #689f38; }

.light-green.darken-3 {
  background-color: #558b2f !important; }

.light-green-text.text-darken-3 {
  color: #558b2f !important; }

/* Fills for SVG */
.light-green-fill.fill-darken-3 {
  fill: #558b2f; }

/* Strokes for SVG */
.light-green-stroke.stroke-darken-3 {
  stroke: #558b2f; }

.light-green.darken-4 {
  background-color: #33691e !important; }

.light-green-text.text-darken-4 {
  color: #33691e !important; }

/* Fills for SVG */
.light-green-fill.fill-darken-4 {
  fill: #33691e; }

/* Strokes for SVG */
.light-green-stroke.stroke-darken-4 {
  stroke: #33691e; }

.light-green.accent-1 {
  background-color: #ccff90 !important; }

.light-green-text.text-accent-1 {
  color: #ccff90 !important; }

/* Fills for SVG */
.light-green-fill.fill-accent-1 {
  fill: #ccff90; }

/* Strokes for SVG */
.light-green-stroke.stroke-accent-1 {
  stroke: #ccff90; }

.light-green.accent-2 {
  background-color: #b2ff59 !important; }

.light-green-text.text-accent-2 {
  color: #b2ff59 !important; }

/* Fills for SVG */
.light-green-fill.fill-accent-2 {
  fill: #b2ff59; }

/* Strokes for SVG */
.light-green-stroke.stroke-accent-2 {
  stroke: #b2ff59; }

.light-green.accent-3 {
  background-color: #76ff03 !important; }

.light-green-text.text-accent-3 {
  color: #76ff03 !important; }

/* Fills for SVG */
.light-green-fill.fill-accent-3 {
  fill: #76ff03; }

/* Strokes for SVG */
.light-green-stroke.stroke-accent-3 {
  stroke: #76ff03; }

.light-green.accent-4 {
  background-color: #64dd17 !important; }

.light-green-text.text-accent-4 {
  color: #64dd17 !important; }

/* Fills for SVG */
.light-green-fill.fill-accent-4 {
  fill: #64dd17; }

/* Strokes for SVG */
.light-green-stroke.stroke-accent-4 {
  stroke: #64dd17; }

.lime {
  background-color: #cddc39 !important; }

.lime-text {
  color: #cddc39 !important; }

/* Fills for SVG */
.lime-fill {
  fill: #cddc39; }

/* Strokes for SVG */
.lime-stroke {
  stroke: #cddc39; }

.lime.lighten-5 {
  background-color: #f9fbe7 !important; }

.lime-text.text-lighten-5 {
  color: #f9fbe7 !important; }

/* Fills for SVG */
.lime-fill.fill-lighten-5 {
  fill: #f9fbe7; }

/* Strokes for SVG */
.lime-stroke.stroke-lighten-5 {
  stroke: #f9fbe7; }

.lime.lighten-4 {
  background-color: #f0f4c3 !important; }

.lime-text.text-lighten-4 {
  color: #f0f4c3 !important; }

/* Fills for SVG */
.lime-fill.fill-lighten-4 {
  fill: #f0f4c3; }

/* Strokes for SVG */
.lime-stroke.stroke-lighten-4 {
  stroke: #f0f4c3; }

.lime.lighten-3 {
  background-color: #e6ee9c !important; }

.lime-text.text-lighten-3 {
  color: #e6ee9c !important; }

/* Fills for SVG */
.lime-fill.fill-lighten-3 {
  fill: #e6ee9c; }

/* Strokes for SVG */
.lime-stroke.stroke-lighten-3 {
  stroke: #e6ee9c; }

.lime.lighten-2 {
  background-color: #dce775 !important; }

.lime-text.text-lighten-2 {
  color: #dce775 !important; }

/* Fills for SVG */
.lime-fill.fill-lighten-2 {
  fill: #dce775; }

/* Strokes for SVG */
.lime-stroke.stroke-lighten-2 {
  stroke: #dce775; }

.lime.lighten-1 {
  background-color: #d4e157 !important; }

.lime-text.text-lighten-1 {
  color: #d4e157 !important; }

/* Fills for SVG */
.lime-fill.fill-lighten-1 {
  fill: #d4e157; }

/* Strokes for SVG */
.lime-stroke.stroke-lighten-1 {
  stroke: #d4e157; }

.lime.darken-1 {
  background-color: #c0ca33 !important; }

.lime-text.text-darken-1 {
  color: #c0ca33 !important; }

/* Fills for SVG */
.lime-fill.fill-darken-1 {
  fill: #c0ca33; }

/* Strokes for SVG */
.lime-stroke.stroke-darken-1 {
  stroke: #c0ca33; }

.lime.darken-2 {
  background-color: #afb42b !important; }

.lime-text.text-darken-2 {
  color: #afb42b !important; }

/* Fills for SVG */
.lime-fill.fill-darken-2 {
  fill: #afb42b; }

/* Strokes for SVG */
.lime-stroke.stroke-darken-2 {
  stroke: #afb42b; }

.lime.darken-3 {
  background-color: #9e9d24 !important; }

.lime-text.text-darken-3 {
  color: #9e9d24 !important; }

/* Fills for SVG */
.lime-fill.fill-darken-3 {
  fill: #9e9d24; }

/* Strokes for SVG */
.lime-stroke.stroke-darken-3 {
  stroke: #9e9d24; }

.lime.darken-4 {
  background-color: #827717 !important; }

.lime-text.text-darken-4 {
  color: #827717 !important; }

/* Fills for SVG */
.lime-fill.fill-darken-4 {
  fill: #827717; }

/* Strokes for SVG */
.lime-stroke.stroke-darken-4 {
  stroke: #827717; }

.lime.accent-1 {
  background-color: #f4ff81 !important; }

.lime-text.text-accent-1 {
  color: #f4ff81 !important; }

/* Fills for SVG */
.lime-fill.fill-accent-1 {
  fill: #f4ff81; }

/* Strokes for SVG */
.lime-stroke.stroke-accent-1 {
  stroke: #f4ff81; }

.lime.accent-2 {
  background-color: #eeff41 !important; }

.lime-text.text-accent-2 {
  color: #eeff41 !important; }

/* Fills for SVG */
.lime-fill.fill-accent-2 {
  fill: #eeff41; }

/* Strokes for SVG */
.lime-stroke.stroke-accent-2 {
  stroke: #eeff41; }

.lime.accent-3 {
  background-color: #c6ff00 !important; }

.lime-text.text-accent-3 {
  color: #c6ff00 !important; }

/* Fills for SVG */
.lime-fill.fill-accent-3 {
  fill: #c6ff00; }

/* Strokes for SVG */
.lime-stroke.stroke-accent-3 {
  stroke: #c6ff00; }

.lime.accent-4 {
  background-color: #aeea00 !important; }

.lime-text.text-accent-4 {
  color: #aeea00 !important; }

/* Fills for SVG */
.lime-fill.fill-accent-4 {
  fill: #aeea00; }

/* Strokes for SVG */
.lime-stroke.stroke-accent-4 {
  stroke: #aeea00; }

.yellow {
  background-color: #ffeb3b !important; }

.yellow-text {
  color: #ffeb3b !important; }

/* Fills for SVG */
.yellow-fill {
  fill: #ffeb3b; }

/* Strokes for SVG */
.yellow-stroke {
  stroke: #ffeb3b; }

.yellow.lighten-5 {
  background-color: #fffde7 !important; }

.yellow-text.text-lighten-5 {
  color: #fffde7 !important; }

/* Fills for SVG */
.yellow-fill.fill-lighten-5 {
  fill: #fffde7; }

/* Strokes for SVG */
.yellow-stroke.stroke-lighten-5 {
  stroke: #fffde7; }

.yellow.lighten-4 {
  background-color: #fff9c4 !important; }

.yellow-text.text-lighten-4 {
  color: #fff9c4 !important; }

/* Fills for SVG */
.yellow-fill.fill-lighten-4 {
  fill: #fff9c4; }

/* Strokes for SVG */
.yellow-stroke.stroke-lighten-4 {
  stroke: #fff9c4; }

.yellow.lighten-3 {
  background-color: #fff59d !important; }

.yellow-text.text-lighten-3 {
  color: #fff59d !important; }

/* Fills for SVG */
.yellow-fill.fill-lighten-3 {
  fill: #fff59d; }

/* Strokes for SVG */
.yellow-stroke.stroke-lighten-3 {
  stroke: #fff59d; }

.yellow.lighten-2 {
  background-color: #fff176 !important; }

.yellow-text.text-lighten-2 {
  color: #fff176 !important; }

/* Fills for SVG */
.yellow-fill.fill-lighten-2 {
  fill: #fff176; }

/* Strokes for SVG */
.yellow-stroke.stroke-lighten-2 {
  stroke: #fff176; }

.yellow.lighten-1 {
  background-color: #ffee58 !important; }

.yellow-text.text-lighten-1 {
  color: #ffee58 !important; }

/* Fills for SVG */
.yellow-fill.fill-lighten-1 {
  fill: #ffee58; }

/* Strokes for SVG */
.yellow-stroke.stroke-lighten-1 {
  stroke: #ffee58; }

.yellow.darken-1 {
  background-color: #fdd835 !important; }

.yellow-text.text-darken-1 {
  color: #fdd835 !important; }

/* Fills for SVG */
.yellow-fill.fill-darken-1 {
  fill: #fdd835; }

/* Strokes for SVG */
.yellow-stroke.stroke-darken-1 {
  stroke: #fdd835; }

.yellow.darken-2 {
  background-color: #fbc02d !important; }

.yellow-text.text-darken-2 {
  color: #fbc02d !important; }

/* Fills for SVG */
.yellow-fill.fill-darken-2 {
  fill: #fbc02d; }

/* Strokes for SVG */
.yellow-stroke.stroke-darken-2 {
  stroke: #fbc02d; }

.yellow.darken-3 {
  background-color: #f9a825 !important; }

.yellow-text.text-darken-3 {
  color: #f9a825 !important; }

/* Fills for SVG */
.yellow-fill.fill-darken-3 {
  fill: #f9a825; }

/* Strokes for SVG */
.yellow-stroke.stroke-darken-3 {
  stroke: #f9a825; }

.yellow.darken-4 {
  background-color: #f57f17 !important; }

.yellow-text.text-darken-4 {
  color: #f57f17 !important; }

/* Fills for SVG */
.yellow-fill.fill-darken-4 {
  fill: #f57f17; }

/* Strokes for SVG */
.yellow-stroke.stroke-darken-4 {
  stroke: #f57f17; }

.yellow.accent-1 {
  background-color: #ffff8d !important; }

.yellow-text.text-accent-1 {
  color: #ffff8d !important; }

/* Fills for SVG */
.yellow-fill.fill-accent-1 {
  fill: #ffff8d; }

/* Strokes for SVG */
.yellow-stroke.stroke-accent-1 {
  stroke: #ffff8d; }

.yellow.accent-2 {
  background-color: #ffff00 !important; }

.yellow-text.text-accent-2 {
  color: #ffff00 !important; }

/* Fills for SVG */
.yellow-fill.fill-accent-2 {
  fill: #ffff00; }

/* Strokes for SVG */
.yellow-stroke.stroke-accent-2 {
  stroke: #ffff00; }

.yellow.accent-3 {
  background-color: #ffea00 !important; }

.yellow-text.text-accent-3 {
  color: #ffea00 !important; }

/* Fills for SVG */
.yellow-fill.fill-accent-3 {
  fill: #ffea00; }

/* Strokes for SVG */
.yellow-stroke.stroke-accent-3 {
  stroke: #ffea00; }

.yellow.accent-4 {
  background-color: #ffd600 !important; }

.yellow-text.text-accent-4 {
  color: #ffd600 !important; }

/* Fills for SVG */
.yellow-fill.fill-accent-4 {
  fill: #ffd600; }

/* Strokes for SVG */
.yellow-stroke.stroke-accent-4 {
  stroke: #ffd600; }

.amber {
  background-color: #ffc107 !important; }

.amber-text {
  color: #ffc107 !important; }

/* Fills for SVG */
.amber-fill {
  fill: #ffc107; }

/* Strokes for SVG */
.amber-stroke {
  stroke: #ffc107; }

.amber.lighten-5 {
  background-color: #fff8e1 !important; }

.amber-text.text-lighten-5 {
  color: #fff8e1 !important; }

/* Fills for SVG */
.amber-fill.fill-lighten-5 {
  fill: #fff8e1; }

/* Strokes for SVG */
.amber-stroke.stroke-lighten-5 {
  stroke: #fff8e1; }

.amber.lighten-4 {
  background-color: #ffecb3 !important; }

.amber-text.text-lighten-4 {
  color: #ffecb3 !important; }

/* Fills for SVG */
.amber-fill.fill-lighten-4 {
  fill: #ffecb3; }

/* Strokes for SVG */
.amber-stroke.stroke-lighten-4 {
  stroke: #ffecb3; }

.amber.lighten-3 {
  background-color: #ffe082 !important; }

.amber-text.text-lighten-3 {
  color: #ffe082 !important; }

/* Fills for SVG */
.amber-fill.fill-lighten-3 {
  fill: #ffe082; }

/* Strokes for SVG */
.amber-stroke.stroke-lighten-3 {
  stroke: #ffe082; }

.amber.lighten-2 {
  background-color: #ffd54f !important; }

.amber-text.text-lighten-2 {
  color: #ffd54f !important; }

/* Fills for SVG */
.amber-fill.fill-lighten-2 {
  fill: #ffd54f; }

/* Strokes for SVG */
.amber-stroke.stroke-lighten-2 {
  stroke: #ffd54f; }

.amber.lighten-1 {
  background-color: #ffca28 !important; }

.amber-text.text-lighten-1 {
  color: #ffca28 !important; }

/* Fills for SVG */
.amber-fill.fill-lighten-1 {
  fill: #ffca28; }

/* Strokes for SVG */
.amber-stroke.stroke-lighten-1 {
  stroke: #ffca28; }

.amber.darken-1 {
  background-color: #ffb300 !important; }

.amber-text.text-darken-1 {
  color: #ffb300 !important; }

/* Fills for SVG */
.amber-fill.fill-darken-1 {
  fill: #ffb300; }

/* Strokes for SVG */
.amber-stroke.stroke-darken-1 {
  stroke: #ffb300; }

.amber.darken-2 {
  background-color: #ffa000 !important; }

.amber-text.text-darken-2 {
  color: #ffa000 !important; }

/* Fills for SVG */
.amber-fill.fill-darken-2 {
  fill: #ffa000; }

/* Strokes for SVG */
.amber-stroke.stroke-darken-2 {
  stroke: #ffa000; }

.amber.darken-3 {
  background-color: #ff8f00 !important; }

.amber-text.text-darken-3 {
  color: #ff8f00 !important; }

/* Fills for SVG */
.amber-fill.fill-darken-3 {
  fill: #ff8f00; }

/* Strokes for SVG */
.amber-stroke.stroke-darken-3 {
  stroke: #ff8f00; }

.amber.darken-4 {
  background-color: #ff6f00 !important; }

.amber-text.text-darken-4 {
  color: #ff6f00 !important; }

/* Fills for SVG */
.amber-fill.fill-darken-4 {
  fill: #ff6f00; }

/* Strokes for SVG */
.amber-stroke.stroke-darken-4 {
  stroke: #ff6f00; }

.amber.accent-1 {
  background-color: #ffe57f !important; }

.amber-text.text-accent-1 {
  color: #ffe57f !important; }

/* Fills for SVG */
.amber-fill.fill-accent-1 {
  fill: #ffe57f; }

/* Strokes for SVG */
.amber-stroke.stroke-accent-1 {
  stroke: #ffe57f; }

.amber.accent-2 {
  background-color: #ffd740 !important; }

.amber-text.text-accent-2 {
  color: #ffd740 !important; }

/* Fills for SVG */
.amber-fill.fill-accent-2 {
  fill: #ffd740; }

/* Strokes for SVG */
.amber-stroke.stroke-accent-2 {
  stroke: #ffd740; }

.amber.accent-3 {
  background-color: #ffc400 !important; }

.amber-text.text-accent-3 {
  color: #ffc400 !important; }

/* Fills for SVG */
.amber-fill.fill-accent-3 {
  fill: #ffc400; }

/* Strokes for SVG */
.amber-stroke.stroke-accent-3 {
  stroke: #ffc400; }

.amber.accent-4 {
  background-color: #ffab00 !important; }

.amber-text.text-accent-4 {
  color: #ffab00 !important; }

/* Fills for SVG */
.amber-fill.fill-accent-4 {
  fill: #ffab00; }

/* Strokes for SVG */
.amber-stroke.stroke-accent-4 {
  stroke: #ffab00; }

.orange {
  background-color: #ff9800 !important; }

.orange-text {
  color: #ff9800 !important; }

/* Fills for SVG */
.orange-fill {
  fill: #ff9800; }

/* Strokes for SVG */
.orange-stroke {
  stroke: #ff9800; }

.orange.lighten-5 {
  background-color: #fff3e0 !important; }

.orange-text.text-lighten-5 {
  color: #fff3e0 !important; }

/* Fills for SVG */
.orange-fill.fill-lighten-5 {
  fill: #fff3e0; }

/* Strokes for SVG */
.orange-stroke.stroke-lighten-5 {
  stroke: #fff3e0; }

.orange.lighten-4 {
  background-color: #ffe0b2 !important; }

.orange-text.text-lighten-4 {
  color: #ffe0b2 !important; }

/* Fills for SVG */
.orange-fill.fill-lighten-4 {
  fill: #ffe0b2; }

/* Strokes for SVG */
.orange-stroke.stroke-lighten-4 {
  stroke: #ffe0b2; }

.orange.lighten-3 {
  background-color: #ffcc80 !important; }

.orange-text.text-lighten-3 {
  color: #ffcc80 !important; }

/* Fills for SVG */
.orange-fill.fill-lighten-3 {
  fill: #ffcc80; }

/* Strokes for SVG */
.orange-stroke.stroke-lighten-3 {
  stroke: #ffcc80; }

.orange.lighten-2 {
  background-color: #ffb74d !important; }

.orange-text.text-lighten-2 {
  color: #ffb74d !important; }

/* Fills for SVG */
.orange-fill.fill-lighten-2 {
  fill: #ffb74d; }

/* Strokes for SVG */
.orange-stroke.stroke-lighten-2 {
  stroke: #ffb74d; }

.orange.lighten-1 {
  background-color: #ffa726 !important; }

.orange-text.text-lighten-1 {
  color: #ffa726 !important; }

/* Fills for SVG */
.orange-fill.fill-lighten-1 {
  fill: #ffa726; }

/* Strokes for SVG */
.orange-stroke.stroke-lighten-1 {
  stroke: #ffa726; }

.orange.darken-1 {
  background-color: #fb8c00 !important; }

.orange-text.text-darken-1 {
  color: #fb8c00 !important; }

/* Fills for SVG */
.orange-fill.fill-darken-1 {
  fill: #fb8c00; }

/* Strokes for SVG */
.orange-stroke.stroke-darken-1 {
  stroke: #fb8c00; }

.orange.darken-2 {
  background-color: #f57c00 !important; }

.orange-text.text-darken-2 {
  color: #f57c00 !important; }

/* Fills for SVG */
.orange-fill.fill-darken-2 {
  fill: #f57c00; }

/* Strokes for SVG */
.orange-stroke.stroke-darken-2 {
  stroke: #f57c00; }

.orange.darken-3 {
  background-color: #ef6c00 !important; }

.orange-text.text-darken-3 {
  color: #ef6c00 !important; }

/* Fills for SVG */
.orange-fill.fill-darken-3 {
  fill: #ef6c00; }

/* Strokes for SVG */
.orange-stroke.stroke-darken-3 {
  stroke: #ef6c00; }

.orange.darken-4 {
  background-color: #e65100 !important; }

.orange-text.text-darken-4 {
  color: #e65100 !important; }

/* Fills for SVG */
.orange-fill.fill-darken-4 {
  fill: #e65100; }

/* Strokes for SVG */
.orange-stroke.stroke-darken-4 {
  stroke: #e65100; }

.orange.accent-1 {
  background-color: #ffd180 !important; }

.orange-text.text-accent-1 {
  color: #ffd180 !important; }

/* Fills for SVG */
.orange-fill.fill-accent-1 {
  fill: #ffd180; }

/* Strokes for SVG */
.orange-stroke.stroke-accent-1 {
  stroke: #ffd180; }

.orange.accent-2 {
  background-color: #ffab40 !important; }

.orange-text.text-accent-2 {
  color: #ffab40 !important; }

/* Fills for SVG */
.orange-fill.fill-accent-2 {
  fill: #ffab40; }

/* Strokes for SVG */
.orange-stroke.stroke-accent-2 {
  stroke: #ffab40; }

.orange.accent-3 {
  background-color: #ff9100 !important; }

.orange-text.text-accent-3 {
  color: #ff9100 !important; }

/* Fills for SVG */
.orange-fill.fill-accent-3 {
  fill: #ff9100; }

/* Strokes for SVG */
.orange-stroke.stroke-accent-3 {
  stroke: #ff9100; }

.orange.accent-4 {
  background-color: #ff6d00 !important; }

.orange-text.text-accent-4 {
  color: #ff6d00 !important; }

/* Fills for SVG */
.orange-fill.fill-accent-4 {
  fill: #ff6d00; }

/* Strokes for SVG */
.orange-stroke.stroke-accent-4 {
  stroke: #ff6d00; }

.deep-orange {
  background-color: #ff5722 !important; }

.deep-orange-text {
  color: #ff5722 !important; }

/* Fills for SVG */
.deep-orange-fill {
  fill: #ff5722; }

/* Strokes for SVG */
.deep-orange-stroke {
  stroke: #ff5722; }

.deep-orange.lighten-5 {
  background-color: #fbe9e7 !important; }

.deep-orange-text.text-lighten-5 {
  color: #fbe9e7 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-lighten-5 {
  fill: #fbe9e7; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-lighten-5 {
  stroke: #fbe9e7; }

.deep-orange.lighten-4 {
  background-color: #ffccbc !important; }

.deep-orange-text.text-lighten-4 {
  color: #ffccbc !important; }

/* Fills for SVG */
.deep-orange-fill.fill-lighten-4 {
  fill: #ffccbc; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-lighten-4 {
  stroke: #ffccbc; }

.deep-orange.lighten-3 {
  background-color: #ffab91 !important; }

.deep-orange-text.text-lighten-3 {
  color: #ffab91 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-lighten-3 {
  fill: #ffab91; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-lighten-3 {
  stroke: #ffab91; }

.deep-orange.lighten-2 {
  background-color: #ff8a65 !important; }

.deep-orange-text.text-lighten-2 {
  color: #ff8a65 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-lighten-2 {
  fill: #ff8a65; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-lighten-2 {
  stroke: #ff8a65; }

.deep-orange.lighten-1 {
  background-color: #ff7043 !important; }

.deep-orange-text.text-lighten-1 {
  color: #ff7043 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-lighten-1 {
  fill: #ff7043; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-lighten-1 {
  stroke: #ff7043; }

.deep-orange.darken-1 {
  background-color: #f4511e !important; }

.deep-orange-text.text-darken-1 {
  color: #f4511e !important; }

/* Fills for SVG */
.deep-orange-fill.fill-darken-1 {
  fill: #f4511e; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-darken-1 {
  stroke: #f4511e; }

.deep-orange.darken-2 {
  background-color: #e64a19 !important; }

.deep-orange-text.text-darken-2 {
  color: #e64a19 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-darken-2 {
  fill: #e64a19; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-darken-2 {
  stroke: #e64a19; }

.deep-orange.darken-3 {
  background-color: #d84315 !important; }

.deep-orange-text.text-darken-3 {
  color: #d84315 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-darken-3 {
  fill: #d84315; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-darken-3 {
  stroke: #d84315; }

.deep-orange.darken-4 {
  background-color: #bf360c !important; }

.deep-orange-text.text-darken-4 {
  color: #bf360c !important; }

/* Fills for SVG */
.deep-orange-fill.fill-darken-4 {
  fill: #bf360c; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-darken-4 {
  stroke: #bf360c; }

.deep-orange.accent-1 {
  background-color: #ff9e80 !important; }

.deep-orange-text.text-accent-1 {
  color: #ff9e80 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-accent-1 {
  fill: #ff9e80; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-accent-1 {
  stroke: #ff9e80; }

.deep-orange.accent-2 {
  background-color: #ff6e40 !important; }

.deep-orange-text.text-accent-2 {
  color: #ff6e40 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-accent-2 {
  fill: #ff6e40; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-accent-2 {
  stroke: #ff6e40; }

.deep-orange.accent-3 {
  background-color: #ff3d00 !important; }

.deep-orange-text.text-accent-3 {
  color: #ff3d00 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-accent-3 {
  fill: #ff3d00; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-accent-3 {
  stroke: #ff3d00; }

.deep-orange.accent-4 {
  background-color: #dd2c00 !important; }

.deep-orange-text.text-accent-4 {
  color: #dd2c00 !important; }

/* Fills for SVG */
.deep-orange-fill.fill-accent-4 {
  fill: #dd2c00; }

/* Strokes for SVG */
.deep-orange-stroke.stroke-accent-4 {
  stroke: #dd2c00; }

.brown {
  background-color: #795548 !important; }

.brown-text {
  color: #795548 !important; }

/* Fills for SVG */
.brown-fill {
  fill: #795548; }

/* Strokes for SVG */
.brown-stroke {
  stroke: #795548; }

.brown.lighten-5 {
  background-color: #efebe9 !important; }

.brown-text.text-lighten-5 {
  color: #efebe9 !important; }

/* Fills for SVG */
.brown-fill.fill-lighten-5 {
  fill: #efebe9; }

/* Strokes for SVG */
.brown-stroke.stroke-lighten-5 {
  stroke: #efebe9; }

.brown.lighten-4 {
  background-color: #d7ccc8 !important; }

.brown-text.text-lighten-4 {
  color: #d7ccc8 !important; }

/* Fills for SVG */
.brown-fill.fill-lighten-4 {
  fill: #d7ccc8; }

/* Strokes for SVG */
.brown-stroke.stroke-lighten-4 {
  stroke: #d7ccc8; }

.brown.lighten-3 {
  background-color: #bcaaa4 !important; }

.brown-text.text-lighten-3 {
  color: #bcaaa4 !important; }

/* Fills for SVG */
.brown-fill.fill-lighten-3 {
  fill: #bcaaa4; }

/* Strokes for SVG */
.brown-stroke.stroke-lighten-3 {
  stroke: #bcaaa4; }

.brown.lighten-2 {
  background-color: #a1887f !important; }

.brown-text.text-lighten-2 {
  color: #a1887f !important; }

/* Fills for SVG */
.brown-fill.fill-lighten-2 {
  fill: #a1887f; }

/* Strokes for SVG */
.brown-stroke.stroke-lighten-2 {
  stroke: #a1887f; }

.brown.lighten-1 {
  background-color: #8d6e63 !important; }

.brown-text.text-lighten-1 {
  color: #8d6e63 !important; }

/* Fills for SVG */
.brown-fill.fill-lighten-1 {
  fill: #8d6e63; }

/* Strokes for SVG */
.brown-stroke.stroke-lighten-1 {
  stroke: #8d6e63; }

.brown.darken-1 {
  background-color: #6d4c41 !important; }

.brown-text.text-darken-1 {
  color: #6d4c41 !important; }

/* Fills for SVG */
.brown-fill.fill-darken-1 {
  fill: #6d4c41; }

/* Strokes for SVG */
.brown-stroke.stroke-darken-1 {
  stroke: #6d4c41; }

.brown.darken-2 {
  background-color: #5d4037 !important; }

.brown-text.text-darken-2 {
  color: #5d4037 !important; }

/* Fills for SVG */
.brown-fill.fill-darken-2 {
  fill: #5d4037; }

/* Strokes for SVG */
.brown-stroke.stroke-darken-2 {
  stroke: #5d4037; }

.brown.darken-3 {
  background-color: #4e342e !important; }

.brown-text.text-darken-3 {
  color: #4e342e !important; }

/* Fills for SVG */
.brown-fill.fill-darken-3 {
  fill: #4e342e; }

/* Strokes for SVG */
.brown-stroke.stroke-darken-3 {
  stroke: #4e342e; }

.brown.darken-4 {
  background-color: #3e2723 !important; }

.brown-text.text-darken-4 {
  color: #3e2723 !important; }

/* Fills for SVG */
.brown-fill.fill-darken-4 {
  fill: #3e2723; }

/* Strokes for SVG */
.brown-stroke.stroke-darken-4 {
  stroke: #3e2723; }

.blue-grey {
  background-color: #607d8b !important; }

.blue-grey-text {
  color: #607d8b !important; }

/* Fills for SVG */
.blue-grey-fill {
  fill: #607d8b; }

/* Strokes for SVG */
.blue-grey-stroke {
  stroke: #607d8b; }

.blue-grey.lighten-5 {
  background-color: #eceff1 !important; }

.blue-grey-text.text-lighten-5 {
  color: #eceff1 !important; }

/* Fills for SVG */
.blue-grey-fill.fill-lighten-5 {
  fill: #eceff1; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-lighten-5 {
  stroke: #eceff1; }

.blue-grey.lighten-4 {
  background-color: #cfd8dc !important; }

.blue-grey-text.text-lighten-4 {
  color: #cfd8dc !important; }

/* Fills for SVG */
.blue-grey-fill.fill-lighten-4 {
  fill: #cfd8dc; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-lighten-4 {
  stroke: #cfd8dc; }

.blue-grey.lighten-3 {
  background-color: #b0bec5 !important; }

.blue-grey-text.text-lighten-3 {
  color: #b0bec5 !important; }

/* Fills for SVG */
.blue-grey-fill.fill-lighten-3 {
  fill: #b0bec5; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-lighten-3 {
  stroke: #b0bec5; }

.blue-grey.lighten-2 {
  background-color: #90a4ae !important; }

.blue-grey-text.text-lighten-2 {
  color: #90a4ae !important; }

/* Fills for SVG */
.blue-grey-fill.fill-lighten-2 {
  fill: #90a4ae; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-lighten-2 {
  stroke: #90a4ae; }

.blue-grey.lighten-1 {
  background-color: #78909c !important; }

.blue-grey-text.text-lighten-1 {
  color: #78909c !important; }

/* Fills for SVG */
.blue-grey-fill.fill-lighten-1 {
  fill: #78909c; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-lighten-1 {
  stroke: #78909c; }

.blue-grey.darken-1 {
  background-color: #546e7a !important; }

.blue-grey-text.text-darken-1 {
  color: #546e7a !important; }

/* Fills for SVG */
.blue-grey-fill.fill-darken-1 {
  fill: #546e7a; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-darken-1 {
  stroke: #546e7a; }

.blue-grey.darken-2 {
  background-color: #455a64 !important; }

.blue-grey-text.text-darken-2 {
  color: #455a64 !important; }

/* Fills for SVG */
.blue-grey-fill.fill-darken-2 {
  fill: #455a64; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-darken-2 {
  stroke: #455a64; }

.blue-grey.darken-3 {
  background-color: #37474f !important; }

.blue-grey-text.text-darken-3 {
  color: #37474f !important; }

/* Fills for SVG */
.blue-grey-fill.fill-darken-3 {
  fill: #37474f; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-darken-3 {
  stroke: #37474f; }

.blue-grey.darken-4 {
  background-color: #263238 !important; }

.blue-grey-text.text-darken-4 {
  color: #263238 !important; }

/* Fills for SVG */
.blue-grey-fill.fill-darken-4 {
  fill: #263238; }

/* Strokes for SVG */
.blue-grey-stroke.stroke-darken-4 {
  stroke: #263238; }

.maroon {
  background-color: #800000 !important; }

.maroon-text {
  color: #800000 !important; }

/* Fills for SVG */
.maroon-fill {
  fill: #800000; }

/* Strokes for SVG */
.maroon-stroke {
  stroke: #800000; }

.maroon.lighten-1 {
  background-color: #952b2b !important; }

.maroon-text.text-lighten-1 {
  color: #952b2b !important; }

/* Fills for SVG */
.maroon-fill.fill-lighten-1 {
  fill: #952b2b; }

/* Strokes for SVG */
.maroon-stroke.stroke-lighten-1 {
  stroke: #952b2b; }

.maroon.lighten-2 {
  background-color: #aa5555 !important; }

.maroon-text.text-lighten-2 {
  color: #aa5555 !important; }

/* Fills for SVG */
.maroon-fill.fill-lighten-2 {
  fill: #aa5555; }

/* Strokes for SVG */
.maroon-stroke.stroke-lighten-2 {
  stroke: #aa5555; }

.maroon.lighten-3 {
  background-color: #c08080 !important; }

.maroon-text.text-lighten-3 {
  color: #c08080 !important; }

/* Fills for SVG */
.maroon-fill.fill-lighten-3 {
  fill: #c08080; }

/* Strokes for SVG */
.maroon-stroke.stroke-lighten-3 {
  stroke: #c08080; }

.maroon.lighten-4 {
  background-color: #d5aaaa !important; }

.maroon-text.text-lighten-4 {
  color: #d5aaaa !important; }

/* Fills for SVG */
.maroon-fill.fill-lighten-4 {
  fill: #d5aaaa; }

/* Strokes for SVG */
.maroon-stroke.stroke-lighten-4 {
  stroke: #d5aaaa; }

.maroon.lighten-5 {
  background-color: #ead5d5 !important; }

.maroon-text.text-lighten-5 {
  color: #ead5d5 !important; }

/* Fills for SVG */
.maroon-fill.fill-lighten-5 {
  fill: #ead5d5; }

/* Strokes for SVG */
.maroon-stroke.stroke-lighten-5 {
  stroke: #ead5d5; }

.maroon.darken-1 {
  background-color: #6b0000 !important; }

.maroon-text.text-darken-1 {
  color: #6b0000 !important; }

/* Fills for SVG */
.maroon-fill.fill-darken-1 {
  fill: #6b0000; }

/* Strokes for SVG */
.maroon-stroke.stroke-darken-1 {
  stroke: #6b0000; }

.maroon.darken-2 {
  background-color: #550000 !important; }

.maroon-text.text-darken-2 {
  color: #550000 !important; }

/* Fills for SVG */
.maroon-fill.fill-darken-2 {
  fill: #550000; }

/* Strokes for SVG */
.maroon-stroke.stroke-darken-2 {
  stroke: #550000; }

.maroon.darken-3 {
  background-color: #400000 !important; }

.maroon-text.text-darken-3 {
  color: #400000 !important; }

/* Fills for SVG */
.maroon-fill.fill-darken-3 {
  fill: #400000; }

/* Strokes for SVG */
.maroon-stroke.stroke-darken-3 {
  stroke: #400000; }

.maroon.darken-4 {
  background-color: #2b0000 !important; }

.maroon-text.text-darken-4 {
  color: #2b0000 !important; }

/* Fills for SVG */
.maroon-fill.fill-darken-4 {
  fill: #2b0000; }

/* Strokes for SVG */
.maroon-stroke.stroke-darken-4 {
  stroke: #2b0000; }

.maroon.darken-5 {
  background-color: #150000 !important; }

.maroon-text.text-darken-5 {
  color: #150000 !important; }

/* Fills for SVG */
.maroon-fill.fill-darken-5 {
  fill: #150000; }

/* Strokes for SVG */
.maroon-stroke.stroke-darken-5 {
  stroke: #150000; }

.navy {
  background-color: #000080 !important; }

.navy-text {
  color: #000080 !important; }

/* Fills for SVG */
.navy-fill {
  fill: #000080; }

/* Strokes for SVG */
.navy-stroke {
  stroke: #000080; }

.navy.lighten-1 {
  background-color: #2b2b95 !important; }

.navy-text.text-lighten-1 {
  color: #2b2b95 !important; }

/* Fills for SVG */
.navy-fill.fill-lighten-1 {
  fill: #2b2b95; }

/* Strokes for SVG */
.navy-stroke.stroke-lighten-1 {
  stroke: #2b2b95; }

.navy.lighten-2 {
  background-color: #5555aa !important; }

.navy-text.text-lighten-2 {
  color: #5555aa !important; }

/* Fills for SVG */
.navy-fill.fill-lighten-2 {
  fill: #5555aa; }

/* Strokes for SVG */
.navy-stroke.stroke-lighten-2 {
  stroke: #5555aa; }

.navy.lighten-3 {
  background-color: #8080c0 !important; }

.navy-text.text-lighten-3 {
  color: #8080c0 !important; }

/* Fills for SVG */
.navy-fill.fill-lighten-3 {
  fill: #8080c0; }

/* Strokes for SVG */
.navy-stroke.stroke-lighten-3 {
  stroke: #8080c0; }

.navy.lighten-4 {
  background-color: #aaaad5 !important; }

.navy-text.text-lighten-4 {
  color: #aaaad5 !important; }

/* Fills for SVG */
.navy-fill.fill-lighten-4 {
  fill: #aaaad5; }

/* Strokes for SVG */
.navy-stroke.stroke-lighten-4 {
  stroke: #aaaad5; }

.navy.lighten-5 {
  background-color: #d5d5ea !important; }

.navy-text.text-lighten-5 {
  color: #d5d5ea !important; }

/* Fills for SVG */
.navy-fill.fill-lighten-5 {
  fill: #d5d5ea; }

/* Strokes for SVG */
.navy-stroke.stroke-lighten-5 {
  stroke: #d5d5ea; }

.navy.darken-1 {
  background-color: #00006b !important; }

.navy-text.text-darken-1 {
  color: #00006b !important; }

/* Fills for SVG */
.navy-fill.fill-darken-1 {
  fill: #00006b; }

/* Strokes for SVG */
.navy-stroke.stroke-darken-1 {
  stroke: #00006b; }

.navy.darken-2 {
  background-color: #000055 !important; }

.navy-text.text-darken-2 {
  color: #000055 !important; }

/* Fills for SVG */
.navy-fill.fill-darken-2 {
  fill: #000055; }

/* Strokes for SVG */
.navy-stroke.stroke-darken-2 {
  stroke: #000055; }

.navy.darken-3 {
  background-color: #000040 !important; }

.navy-text.text-darken-3 {
  color: #000040 !important; }

/* Fills for SVG */
.navy-fill.fill-darken-3 {
  fill: #000040; }

/* Strokes for SVG */
.navy-stroke.stroke-darken-3 {
  stroke: #000040; }

.navy.darken-4 {
  background-color: #00002b !important; }

.navy-text.text-darken-4 {
  color: #00002b !important; }

/* Fills for SVG */
.navy-fill.fill-darken-4 {
  fill: #00002b; }

/* Strokes for SVG */
.navy-stroke.stroke-darken-4 {
  stroke: #00002b; }

.navy.darken-5 {
  background-color: #000015 !important; }

.navy-text.text-darken-5 {
  color: #000015 !important; }

/* Fills for SVG */
.navy-fill.fill-darken-5 {
  fill: #000015; }

/* Strokes for SVG */
.navy-stroke.stroke-darken-5 {
  stroke: #000015; }

.grey {
  background-color: #9e9e9e !important; }

.grey-text {
  color: #9e9e9e !important; }

/* Fills for SVG */
.grey-fill {
  fill: #9e9e9e; }

/* Strokes for SVG */
.grey-stroke {
  stroke: #9e9e9e; }

.grey.lighten-5 {
  background-color: #fafafa !important; }

.grey-text.text-lighten-5 {
  color: #fafafa !important; }

/* Fills for SVG */
.grey-fill.fill-lighten-5 {
  fill: #fafafa; }

/* Strokes for SVG */
.grey-stroke.stroke-lighten-5 {
  stroke: #fafafa; }

.grey.lighten-4 {
  background-color: #f5f5f5 !important; }

.grey-text.text-lighten-4 {
  color: #f5f5f5 !important; }

/* Fills for SVG */
.grey-fill.fill-lighten-4 {
  fill: #f5f5f5; }

/* Strokes for SVG */
.grey-stroke.stroke-lighten-4 {
  stroke: #f5f5f5; }

.grey.lighten-3 {
  background-color: #eeeeee !important; }

.grey-text.text-lighten-3 {
  color: #eeeeee !important; }

/* Fills for SVG */
.grey-fill.fill-lighten-3 {
  fill: #eeeeee; }

/* Strokes for SVG */
.grey-stroke.stroke-lighten-3 {
  stroke: #eeeeee; }

.grey.lighten-2 {
  background-color: #e0e0e0 !important; }

.grey-text.text-lighten-2 {
  color: #e0e0e0 !important; }

/* Fills for SVG */
.grey-fill.fill-lighten-2 {
  fill: #e0e0e0; }

/* Strokes for SVG */
.grey-stroke.stroke-lighten-2 {
  stroke: #e0e0e0; }

.grey.lighten-1 {
  background-color: #bdbdbd !important; }

.grey-text.text-lighten-1 {
  color: #bdbdbd !important; }

/* Fills for SVG */
.grey-fill.fill-lighten-1 {
  fill: #bdbdbd; }

/* Strokes for SVG */
.grey-stroke.stroke-lighten-1 {
  stroke: #bdbdbd; }

.grey.darken-1 {
  background-color: #757575 !important; }

.grey-text.text-darken-1 {
  color: #757575 !important; }

/* Fills for SVG */
.grey-fill.fill-darken-1 {
  fill: #757575; }

/* Strokes for SVG */
.grey-stroke.stroke-darken-1 {
  stroke: #757575; }

.grey.darken-2 {
  background-color: #616161 !important; }

.grey-text.text-darken-2 {
  color: #616161 !important; }

/* Fills for SVG */
.grey-fill.fill-darken-2 {
  fill: #616161; }

/* Strokes for SVG */
.grey-stroke.stroke-darken-2 {
  stroke: #616161; }

.grey.darken-3 {
  background-color: #424242 !important; }

.grey-text.text-darken-3 {
  color: #424242 !important; }

/* Fills for SVG */
.grey-fill.fill-darken-3 {
  fill: #424242; }

/* Strokes for SVG */
.grey-stroke.stroke-darken-3 {
  stroke: #424242; }

.grey.darken-4 {
  background-color: #212121 !important; }

.grey-text.text-darken-4 {
  color: #212121 !important; }

/* Fills for SVG */
.grey-fill.fill-darken-4 {
  fill: #212121; }

/* Strokes for SVG */
.grey-stroke.stroke-darken-4 {
  stroke: #212121; }

.green-forest {
  background-color: #008000 !important; }

.green-forest-text {
  color: #008000 !important; }

/* Fills for SVG */
.green-forest-fill {
  fill: #008000; }

/* Strokes for SVG */
.green-forest-stroke {
  stroke: #008000; }

.green-forest.lighten-1 {
  background-color: #2b952b !important; }

.green-forest-text.text-lighten-1 {
  color: #2b952b !important; }

/* Fills for SVG */
.green-forest-fill.fill-lighten-1 {
  fill: #2b952b; }

/* Strokes for SVG */
.green-forest-stroke.stroke-lighten-1 {
  stroke: #2b952b; }

.green-forest.lighten-2 {
  background-color: #55aa55 !important; }

.green-forest-text.text-lighten-2 {
  color: #55aa55 !important; }

/* Fills for SVG */
.green-forest-fill.fill-lighten-2 {
  fill: #55aa55; }

/* Strokes for SVG */
.green-forest-stroke.stroke-lighten-2 {
  stroke: #55aa55; }

.green-forest.lighten-3 {
  background-color: #80c080 !important; }

.green-forest-text.text-lighten-3 {
  color: #80c080 !important; }

/* Fills for SVG */
.green-forest-fill.fill-lighten-3 {
  fill: #80c080; }

/* Strokes for SVG */
.green-forest-stroke.stroke-lighten-3 {
  stroke: #80c080; }

.green-forest.lighten-4 {
  background-color: #aad5aa !important; }

.green-forest-text.text-lighten-4 {
  color: #aad5aa !important; }

/* Fills for SVG */
.green-forest-fill.fill-lighten-4 {
  fill: #aad5aa; }

/* Strokes for SVG */
.green-forest-stroke.stroke-lighten-4 {
  stroke: #aad5aa; }

.green-forest.lighten-5 {
  background-color: #d5ead5 !important; }

.green-forest-text.text-lighten-5 {
  color: #d5ead5 !important; }

/* Fills for SVG */
.green-forest-fill.fill-lighten-5 {
  fill: #d5ead5; }

/* Strokes for SVG */
.green-forest-stroke.stroke-lighten-5 {
  stroke: #d5ead5; }

.green-forest.darken-1 {
  background-color: #006b00 !important; }

.green-forest-text.text-darken-1 {
  color: #006b00 !important; }

/* Fills for SVG */
.green-forest-fill.fill-darken-1 {
  fill: #006b00; }

/* Strokes for SVG */
.green-forest-stroke.stroke-darken-1 {
  stroke: #006b00; }

.green-forest.darken-2 {
  background-color: #005500 !important; }

.green-forest-text.text-darken-2 {
  color: #005500 !important; }

/* Fills for SVG */
.green-forest-fill.fill-darken-2 {
  fill: #005500; }

/* Strokes for SVG */
.green-forest-stroke.stroke-darken-2 {
  stroke: #005500; }

.green-forest.darken-3 {
  background-color: #004000 !important; }

.green-forest-text.text-darken-3 {
  color: #004000 !important; }

/* Fills for SVG */
.green-forest-fill.fill-darken-3 {
  fill: #004000; }

/* Strokes for SVG */
.green-forest-stroke.stroke-darken-3 {
  stroke: #004000; }

.green-forest.darken-4 {
  background-color: #002b00 !important; }

.green-forest-text.text-darken-4 {
  color: #002b00 !important; }

/* Fills for SVG */
.green-forest-fill.fill-darken-4 {
  fill: #002b00; }

/* Strokes for SVG */
.green-forest-stroke.stroke-darken-4 {
  stroke: #002b00; }

.green-forest.darken-5 {
  background-color: #001500 !important; }

.green-forest-text.text-darken-5 {
  color: #001500 !important; }

/* Fills for SVG */
.green-forest-fill.fill-darken-5 {
  fill: #001500; }

/* Strokes for SVG */
.green-forest-stroke.stroke-darken-5 {
  stroke: #001500; }

.black {
  background-color: #000000 !important; }

.black-text {
  color: #000000 !important; }

/* Fills for SVG */
.black-fill {
  fill: #000000; }

/* Strokes for SVG */
.black-stroke {
  stroke: #000000; }

.white {
  background-color: #FFFFFF !important; }

.white-text {
  color: #FFFFFF !important; }

/* Fills for SVG */
.white-fill {
  fill: #FFFFFF; }

/* Strokes for SVG */
.white-stroke {
  stroke: #FFFFFF; }

.transparent {
  background-color: transparent !important; }

.transparent-text {
  color: transparent !important; }

/* Fills for SVG */
.transparent-fill {
  fill: transparent; }

/* Strokes for SVG */
.transparent-stroke {
  stroke: transparent; }

/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
/**
 * 1. Set default font family to sans-serif.
 * 2. Prevent iOS and IE text size adjust after device orientation change,
 *    without disabling user zoom.
 */
html {
  /*font-family: sans-serif; 1 */
  -ms-text-size-adjust: 100%;
  /* 2 */
  -webkit-text-size-adjust: 100%;
  /* 2 */ }

/**
 * Remove default margin.
 */
body {
  margin: 0; }

/* HTML5 display definitions
   ========================================================================== */
/**
 * Correct `block` display not defined for any HTML5 element in IE 8/9.
 * Correct `block` display not defined for `details` or `summary` in IE 10/11
 * and Firefox.
 * Correct `block` display not defined for `main` in IE 11.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
  display: block; }

/**
 * 1. Correct `inline-block` display not defined in IE 8/9.
 * 2. Normalize vertical alignment of `progress` in Chrome, Firefox, and Opera.
 */
audio,
canvas,
progress,
video {
  display: inline-block;
  /* 1 */
  vertical-align: baseline;
  /* 2 */ }

/**
 * Prevent modern browsers from displaying `audio` without controls.
 * Remove excess height in iOS 5 devices.
 */
audio:not([controls]) {
  display: none;
  height: 0; }

/**
 * Address `[hidden]` styling not present in IE 8/9/10.
 * Hide the `template` element in IE 8/9/10/11, Safari, and Firefox < 22.
 */
[hidden],
template {
  display: none; }

/* Links
   ========================================================================== */
/**
 * Remove the gray background color from active links in IE 10.
 */
a {
  background-color: transparent; }

/**
 * Improve readability of focused elements when they are also in an
 * active/hover state.
 */
a:active,
a:hover {
  outline: 0; }

/* Text-level semantics
   ========================================================================== */
/**
 * Address styling not present in IE 8/9/10/11, Safari, and Chrome.
 */
abbr[title] {
  border-bottom: 1px dotted; }

/**
 * Address style set to `bolder` in Firefox 4+, Safari, and Chrome.
 */
b,
strong {
  font-weight: bold; }

/**
 * Address styling not present in Safari and Chrome.
 */
dfn {
  font-style: italic; }

/**
 * Address variable `h1` font-size and margin within `section` and `article`
 * contexts in Firefox 4+, Safari, and Chrome.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0; }

/**
 * Address styling not present in IE 8/9.
 */
mark {
  background: #ff0;
  color: #000; }

/**
 * Address inconsistent and variable font size in all browsers.
 */
small {
  font-size: 80%; }

/**
 * Prevent `sub` and `sup` affecting `line-height` in all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sup {
  top: -0.5em; }

sub {
  bottom: -0.25em; }

/* Embedded content
   ========================================================================== */
/**
 * Remove border when inside `a` element in IE 8/9/10.
 */
img {
  border: 0; }

/**
 * Correct overflow not hidden in IE 9/10/11.
 */
svg:not(:root) {
  overflow: hidden; }

/* Grouping content
   ========================================================================== */
/**
 * Address margin not present in IE 8/9 and Safari.
 */
figure {
  margin: 1em 40px; }

/**
 * Address differences between Firefox and other browsers.
 */
hr {
  box-sizing: content-box;
  height: 0; }

/**
 * Contain overflow in all browsers.
 */
pre {
  overflow: auto; }

/**
 * Address odd `em`-unit font size rendering in all browsers.
 */
code,
kbd,
pre,
samp {
  font-family: monospace, monospace;
  font-size: 1em; }

/* Forms
   ========================================================================== */
/**
 * Known limitation: by default, Chrome and Safari on OS X allow very limited
 * styling of `select`, unless a `border` property is set.
 */
/**
 * 1. Correct color not being inherited.
 *    Known issue: affects color of disabled elements.
 * 2. Correct font properties not being inherited.
 * 3. Address margins set differently in Firefox 4+, Safari, and Chrome.
 */
button,
input,
optgroup,
select,
textarea {
  color: inherit;
  /* 1 */
  font: inherit;
  /* 2 */
  margin: 0;
  /* 3 */ }

/**
 * Address `overflow` set to `hidden` in IE 8/9/10/11.
 */
button {
  overflow: visible; }

/**
 * Address inconsistent `text-transform` inheritance for `button` and `select`.
 * All other form control elements do not inherit `text-transform` values.
 * Correct `button` style inheritance in Firefox, IE 8/9/10/11, and Opera.
 * Correct `select` style inheritance in Firefox.
 */
button,
select {
  text-transform: none; }

/**
 * 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
 *    and `video` controls.
 * 2. Correct inability to style clickable `input` types in iOS.
 * 3. Improve usability and consistency of cursor style between image-type
 *    `input` and others.
 */
button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  /* 2 */
  cursor: pointer;
  /* 3 */ }

/**
 * Re-set default cursor for disabled elements.
 */
button[disabled],
html input[disabled] {
  cursor: default; }

/**
 * Remove inner padding and border in Firefox 4+.
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0; }

/**
 * Address Firefox 4+ setting `line-height` on `input` using `!important` in
 * the UA stylesheet.
 */
input {
  line-height: normal; }

/**
 * It's recommended that you don't attempt to style these elements.
 * Firefox's implementation doesn't respect box-sizing, padding, or width.
 *
 * 1. Address box sizing set to `content-box` in IE 8/9/10.
 * 2. Remove excess padding in IE 8/9/10.
 */
input[type="checkbox"],
input[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Fix the cursor style for Chrome's increment/decrement buttons. For certain
 * `font-size` values of the `input`, it causes the cursor style of the
 * decrement button to change from `default` to `text`.
 */
input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
  height: auto; }

/**
 * 1. Address `appearance` set to `searchfield` in Safari and Chrome.
 * 2. Address `box-sizing` set to `border-box` in Safari and Chrome.
 */
input[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  box-sizing: content-box;
  /* 2 */ }

/**
 * Remove inner padding and search cancel button in Safari and Chrome on OS X.
 * Safari (but not Chrome) clips the cancel button when the search input has
 * padding (and `textfield` appearance).
 */
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none; }

/**
 * Define consistent border, margin, and padding.
 */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em; }

/**
 * 1. Correct `color` not being inherited in IE 8/9/10/11.
 * 2. Remove padding so people aren't caught out if they zero out fieldsets.
 */
legend {
  border: 0;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * Remove default vertical scrollbar in IE 8/9/10/11.
 */
textarea {
  overflow: auto; }

/**
 * Don't inherit the `font-weight` (applied by a rule above).
 * NOTE: the default cannot safely be changed in Chrome and Safari on OS X.
 */
optgroup {
  font-weight: bold; }

/* Tables
   ========================================================================== */
/**
 * Remove most spacing between table cells.
 */
table {
  border-collapse: collapse;
  border-spacing: 0; }

td,
th {
  padding: 0; }

html {
  box-sizing: border-box; }

*, *:before, *:after {
  box-sizing: inherit; }

ul:not(.browser-default) {
  padding-left: 0;
  list-style-type: none; }
  ul:not(.browser-default) li {
    list-style-type: none; }

a {
  color: #039be5;
  text-decoration: none;
  -webkit-tap-highlight-color: transparent; }

.valign-wrapper {
  display: flex;
  align-items: center; }
  .valign-wrapper .valign {
    display: block; }

.clearfix {
  clear: both; }

.bold {
  font-weight: bold; }

.fs8 {
  font-size: 0.8rem; }

.z-depth-0 {
  box-shadow: none !important; }

.z-depth-1, .btn, .btn-large, .btn-floating, .card-panel, .card, .dropdown-content, .toast {
  box-shadow: 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2); }

.z-depth-1-half, .btn:hover, .btn-large:hover, .btn-floating:hover {
  box-shadow: 0 3px 3px 0 rgba(0, 0, 0, 0.14), 0 1px 7px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -1px rgba(0, 0, 0, 0.2); }

.z-depth-2 {
  box-shadow: 0 4px 5px 0 rgba(0, 0, 0, 0.14), 0 1px 10px 0 rgba(0, 0, 0, 0.12), 0 2px 4px -1px rgba(0, 0, 0, 0.3); }

.z-depth-3 {
  box-shadow: 0 6px 10px 0 rgba(0, 0, 0, 0.14), 0 1px 18px 0 rgba(0, 0, 0, 0.12), 0 3px 5px -1px rgba(0, 0, 0, 0.3); }

.z-depth-4, .modal {
  box-shadow: 0 8px 10px 1px rgba(0, 0, 0, 0.14), 0 3px 14px 2px rgba(0, 0, 0, 0.12), 0 5px 5px -3px rgba(0, 0, 0, 0.3); }

.z-depth-5 {
  box-shadow: 0 16px 24px 2px rgba(0, 0, 0, 0.14), 0 6px 30px 5px rgba(0, 0, 0, 0.12), 0 8px 10px -5px rgba(0, 0, 0, 0.3); }

.hoverable {
  transition: box-shadow .25s;
  box-shadow: 0; }

.hoverable:hover {
  transition: box-shadow .25s;
  box-shadow: 0 8px 17px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19); }

.divider {
  height: 1px;
  overflow: hidden;
  background-color: #e0e0e0; }

blockquote {
  margin: 20px 0;
  padding-left: 1.5rem;
  border-left: 5px solid #ee6e73; }

i {
  line-height: inherit; }
  i.left {
    float: left;
    margin-right: 15px; }
  i.right {
    float: right;
    margin-left: 15px; }
  i.tiny {
    font-size: 1rem; }
  i.small {
    font-size: 2rem; }
  i.medium {
    font-size: 4rem; }
  i.large {
    font-size: 6rem; }

img.responsive-img,
video.responsive-video {
  max-width: 100%;
  height: auto; }

.pagination li {
  display: inline-block;
  border-radius: 2px;
  text-align: center;
  vertical-align: top;
  height: 30px; }
  .pagination li a {
    color: #444;
    display: inline-block;
    font-size: 1.2rem;
    padding: 0 10px;
    line-height: 30px; }
  .pagination li.active a {
    color: #fff; }
  .pagination li.active {
    background-color: #ee6e73; }
  .pagination li.disabled a {
    cursor: default;
    color: #999; }
  .pagination li i {
    font-size: 2rem; }
.pagination li.pages ul li {
  display: inline-block;
  float: none; }

@media only screen and (max-width: 992px) {
  .pagination {
    width: 100%; }
    .pagination li.prev,
    .pagination li.next {
      width: 10%; }
    .pagination li.pages {
      width: 80%;
      overflow: hidden;
      white-space: nowrap; } }
.breadcrumb {
  font-size: 18px;
  color: rgba(255, 255, 255, 0.7); }
  .breadcrumb i,
  .breadcrumb [class^="mdi-"], .breadcrumb [class*="mdi-"],
  .breadcrumb i.material-icons {
    display: inline-block;
    float: left;
    font-size: 24px; }
  .breadcrumb:after {
    content: '\E5CC';
    color: rgba(255, 255, 255, 0.7);
    vertical-align: top;
    display: inline-block;
    font-family: 'Material Icons';
    font-weight: normal;
    font-style: normal;
    font-size: 25px;
    margin: 0 10px 0 8px;
    -webkit-font-smoothing: antialiased; }
  .breadcrumb:last-child:after {
    display: none; }
  .breadcrumb:last-child {
    color: #fff; }

.parallax-container {
  position: relative;
  overflow: hidden;
  height: 500px; }

.parallax {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: -1; }
  .parallax img {
    display: none;
    position: absolute;
    left: 50%;
    bottom: 0;
    min-width: 100%;
    min-height: 100%;
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0);
    transform: translateX(-50%); }

.pin-top, .pin-bottom {
  position: relative; }

.pinned {
  position: fixed !important; }

/*********************
  Transition Classes
**********************/
ul.staggered-list li {
  opacity: 0; }

.fade-in {
  opacity: 0;
  transform-origin: 0 50%; }

/*********************
  Media Query Classes
**********************/
@media only screen and (max-width: 600px) {
  .hide-on-small-only, .hide-on-small-and-down {
    display: none !important; } }

@media only screen and (max-width: 992px) {
  .hide-on-med-and-down {
    display: none !important; } }

@media only screen and (min-width: 601px) {
  .hide-on-med-and-up {
    display: none !important; } }

@media only screen and (min-width: 600px) and (max-width: 992px) {
  .hide-on-med-only {
    display: none !important; } }

@media only screen and (min-width: 993px) {
  .hide-on-large-only {
    display: none !important; } }

@media only screen and (min-width: 993px) {
  .show-on-large {
    display: block !important; } }

@media only screen and (min-width: 600px) and (max-width: 992px) {
  .show-on-medium {
    display: block !important; } }

@media only screen and (max-width: 600px) {
  .show-on-small {
    display: block !important; } }

@media only screen and (min-width: 601px) {
  .show-on-medium-and-up {
    display: block !important; } }

@media only screen and (max-width: 992px) {
  .show-on-medium-and-down {
    display: block !important; } }

@media only screen and (max-width: 600px) {
  .center-on-small-only {
    text-align: center; } }

footer.page-footer {
  margin-top: 20px;
  padding-top: 20px;
  background-color: #ee6e73; }
  footer.page-footer .footer-copyright {
    overflow: hidden;
    height: 50px;
    line-height: 50px;
    color: rgba(255, 255, 255, 0.8);
    background-color: rgba(51, 51, 51, 0.08); }

table, th, td {
  border: none; }

table {
  width: 100%;
  display: table; }
  table.bordered > thead > tr, table.bordered > tbody > tr {
    border-bottom: 1px solid #d0d0d0; }
  table.striped > tbody > tr:nth-child(odd) {
    background-color: #f2f2f2; }
  table.striped > tbody > tr > td {
    border-radius: 0; }
  table.highlight > tbody > tr {
    transition: background-color .25s ease; }
    table.highlight > tbody > tr:hover {
      background-color: #f2f2f2; }
  table.centered thead tr th, table.centered tbody tr td {
    text-align: center; }

thead {
  border-bottom: 1px solid #d0d0d0; }

td, th {
  padding: 10px 5px;
  display: table-cell;
  text-align: left;
  vertical-align: middle;
  border-radius: 2px; }

@media only screen and (max-width: 992px) {
  table.responsive-table {
    width: 100%;
    border-collapse: collapse;
    border-spacing: 0;
    display: block;
    position: relative;
    /* sort out borders */ }
    table.responsive-table td:empty:before {
      content: '\00a0'; }
    table.responsive-table th,
    table.responsive-table td {
      margin: 0;
      vertical-align: top; }
    table.responsive-table th {
      text-align: left; }
    table.responsive-table thead {
      display: block;
      float: left; }
      table.responsive-table thead tr {
        display: block;
        padding: 0 10px 0 0; }
        table.responsive-table thead tr th::before {
          content: "\00a0"; }
    table.responsive-table tbody {
      display: block;
      width: auto;
      position: relative;
      overflow-x: auto;
      white-space: nowrap; }
      table.responsive-table tbody tr {
        display: inline-block;
        vertical-align: top; }
    table.responsive-table th {
      display: block;
      text-align: right; }
    table.responsive-table td {
      display: block;
      min-height: 1.25em;
      text-align: left; }
    table.responsive-table tr {
      padding: 0 10px; }
    table.responsive-table thead {
      border: 0;
      border-right: 1px solid #d0d0d0; }
    table.responsive-table.bordered th {
      border-bottom: 0;
      border-left: 0; }
    table.responsive-table.bordered td {
      border-left: 0;
      border-right: 0;
      border-bottom: 0; }
    table.responsive-table.bordered tr {
      border: 0; }
    table.responsive-table.bordered tbody tr {
      border-right: 1px solid #d0d0d0; } }
.collection {
  margin: 0.5rem 0 1rem 0;
  border: 1px solid #e0e0e0;
  border-radius: 2px;
  overflow: hidden;
  position: relative; }
  .collection .collection-item {
    background-color: #fff;
    line-height: 1.5rem;
    padding: 10px 20px;
    margin: 0;
    border-bottom: 1px solid #e0e0e0; }
    .collection .collection-item.avatar {
      min-height: 84px;
      padding-left: 72px;
      position: relative; }
      .collection .collection-item.avatar .circle {
        position: absolute;
        width: 42px;
        height: 42px;
        overflow: hidden;
        left: 15px;
        display: inline-block;
        vertical-align: middle; }
      .collection .collection-item.avatar i.circle {
        font-size: 18px;
        line-height: 42px;
        color: #fff;
        background-color: #999;
        text-align: center; }
      .collection .collection-item.avatar .title {
        font-size: 16px; }
      .collection .collection-item.avatar p {
        margin: 0; }
      .collection .collection-item.avatar .secondary-content {
        position: absolute;
        top: 16px;
        right: 16px; }
    .collection .collection-item:last-child {
      border-bottom: none; }
    .collection .collection-item.active {
      background-color: #26a69a;
      color: #eafaf9; }
      .collection .collection-item.active .secondary-content {
        color: #fff; }
  .collection a.collection-item {
    display: block;
    transition: .25s;
    color: #26a69a; }
    .collection a.collection-item:not(.active):hover {
      background-color: #ddd; }
  .collection.with-header .collection-header {
    background-color: #fff;
    border-bottom: 1px solid #e0e0e0;
    padding: 10px 20px; }
  .collection.with-header .collection-item {
    padding-left: 30px; }
  .collection.with-header .collection-item.avatar {
    padding-left: 72px; }

.secondary-content {
  float: right;
  color: #26a69a; }

.collapsible .collection {
  margin: 0;
  border: none; }

span.badge {
  min-width: 3rem;
  padding: 0 6px;
  margin-left: 14px;
  text-align: center;
  font-size: 1rem;
  line-height: inherit;
  color: #757575;
  float: right;
  box-sizing: border-box; }
  span.badge.new {
    font-weight: 300;
    font-size: 0.8rem;
    color: #fff;
    background-color: #26a69a;
    border-radius: 2px; }
  span.badge.new:after {
    content: " new"; }
  span.badge[data-badge-caption]::after {
    content: " " attr(data-badge-caption); }

nav ul a span.badge {
  display: inline-block;
  float: none;
  margin-left: 4px;
  line-height: 22px;
  height: 22px; }

.side-nav span.badge.new,
.collapsible span.badge.new {
  position: relative;
  background-color: transparent; }
  .side-nav span.badge.new::before,
  .collapsible span.badge.new::before {
    content: '';
    position: absolute;
    top: 10px;
    right: 0;
    bottom: 10px;
    left: 0;
    background-color: #26a69a;
    border-radius: 2px;
    z-index: -1; }

.collapsible span.badge.new {
  z-index: 1; }

.video-container {
  position: relative;
  padding-bottom: 56.25%;
  height: 0;
  overflow: hidden; }
  .video-container iframe, .video-container object, .video-container embed {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; }

.progress {
  position: relative;
  height: 4px;
  display: block;
  width: 100%;
  background-color: #acece6;
  border-radius: 2px;
  margin: 0.5rem 0 1rem 0;
  overflow: hidden; }
  .progress .determinate {
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    background-color: #26a69a;
    transition: width .3s linear; }
  .progress .indeterminate {
    background-color: #26a69a; }
    .progress .indeterminate:before {
      content: '';
      position: absolute;
      background-color: inherit;
      top: 0;
      left: 0;
      bottom: 0;
      will-change: left, right;
      animation: indeterminate 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite; }
    .progress .indeterminate:after {
      content: '';
      position: absolute;
      background-color: inherit;
      top: 0;
      left: 0;
      bottom: 0;
      will-change: left, right;
      animation: indeterminate-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;
      animation-delay: 1.15s; }

@keyframes indeterminate {
  0% {
    left: -35%;
    right: 100%; }
  60% {
    left: 100%;
    right: -90%; }
  100% {
    left: 100%;
    right: -90%; } }
@keyframes indeterminate-short {
  0% {
    left: -200%;
    right: 100%; }
  60% {
    left: 107%;
    right: -8%; }
  100% {
    left: 107%;
    right: -8%; } }
/*******************
  Utility Classes
*******************/
.hide {
  display: none !important; }

.left-align {
  text-align: left; }

.right-align {
  text-align: right; }

.center, .center-align {
  text-align: center; }

.left {
  float: left !important; }

.right {
  float: right !important; }

.no-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.circle {
  border-radius: 50%; }

.center-block {
  display: block;
  margin-left: auto;
  margin-right: auto; }

.truncate {
  display: block;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.no-padding {
  padding: 0 !important; }

.container {
  margin: 0 auto;
  max-width: 1280px;
  width: 90%; }

@media only screen and (min-width: 601px) {
  .container {
    width: 85%; } }
@media only screen and (min-width: 993px) {
  .container {
    width: 90%; } }
.container .row {
  margin-left: -0.75rem;
  margin-right: -0.75rem; }

.section {
  padding-top: 1rem;
  padding-bottom: 1rem; }
  .section.no-pad {
    padding: 0; }
  .section.no-pad-bot {
    padding-bottom: 0; }
  .section.no-pad-top {
    padding-top: 0; }

.row {
  margin-left: auto;
  margin-right: auto;
  margin-bottom: 20px; }
  .row:after {
    content: "";
    display: table;
    clear: both; }
  .row .col {
    float: left;
    box-sizing: border-box;
    padding: 0 0.75rem;
    min-height: 1px; }
    .row .col[class*="push-"], .row .col[class*="pull-"] {
      position: relative; }
    .row .col.s1 {
      width: 8.3333333333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s2 {
      width: 16.6666666667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s3 {
      width: 25%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s4 {
      width: 33.3333333333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s5 {
      width: 41.6666666667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s6 {
      width: 50%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s7 {
      width: 58.3333333333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s8 {
      width: 66.6666666667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s9 {
      width: 75%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s10 {
      width: 83.3333333333%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s11 {
      width: 91.6666666667%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.s12 {
      width: 100%;
      margin-left: auto;
      left: auto;
      right: auto; }
    .row .col.offset-s1 {
      margin-left: 8.3333333333%; }
    .row .col.pull-s1 {
      right: 8.3333333333%; }
    .row .col.push-s1 {
      left: 8.3333333333%; }
    .row .col.offset-s2 {
      margin-left: 16.6666666667%; }
    .row .col.pull-s2 {
      right: 16.6666666667%; }
    .row .col.push-s2 {
      left: 16.6666666667%; }
    .row .col.offset-s3 {
      margin-left: 25%; }
    .row .col.pull-s3 {
      right: 25%; }
    .row .col.push-s3 {
      left: 25%; }
    .row .col.offset-s4 {
      margin-left: 33.3333333333%; }
    .row .col.pull-s4 {
      right: 33.3333333333%; }
    .row .col.push-s4 {
      left: 33.3333333333%; }
    .row .col.offset-s5 {
      margin-left: 41.6666666667%; }
    .row .col.pull-s5 {
      right: 41.6666666667%; }
    .row .col.push-s5 {
      left: 41.6666666667%; }
    .row .col.offset-s6 {
      margin-left: 50%; }
    .row .col.pull-s6 {
      right: 50%; }
    .row .col.push-s6 {
      left: 50%; }
    .row .col.offset-s7 {
      margin-left: 58.3333333333%; }
    .row .col.pull-s7 {
      right: 58.3333333333%; }
    .row .col.push-s7 {
      left: 58.3333333333%; }
    .row .col.offset-s8 {
      margin-left: 66.6666666667%; }
    .row .col.pull-s8 {
      right: 66.6666666667%; }
    .row .col.push-s8 {
      left: 66.6666666667%; }
    .row .col.offset-s9 {
      margin-left: 75%; }
    .row .col.pull-s9 {
      right: 75%; }
    .row .col.push-s9 {
      left: 75%; }
    .row .col.offset-s10 {
      margin-left: 83.3333333333%; }
    .row .col.pull-s10 {
      right: 83.3333333333%; }
    .row .col.push-s10 {
      left: 83.3333333333%; }
    .row .col.offset-s11 {
      margin-left: 91.6666666667%; }
    .row .col.pull-s11 {
      right: 91.6666666667%; }
    .row .col.push-s11 {
      left: 91.6666666667%; }
    .row .col.offset-s12 {
      margin-left: 100%; }
    .row .col.pull-s12 {
      right: 100%; }
    .row .col.push-s12 {
      left: 100%; }
    @media only screen and (min-width: 601px) {
      .row .col.m1 {
        width: 8.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m2 {
        width: 16.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m3 {
        width: 25%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m4 {
        width: 33.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m5 {
        width: 41.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m6 {
        width: 50%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m7 {
        width: 58.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m8 {
        width: 66.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m9 {
        width: 75%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m10 {
        width: 83.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m11 {
        width: 91.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.m12 {
        width: 100%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.offset-m1 {
        margin-left: 8.3333333333%; }
      .row .col.pull-m1 {
        right: 8.3333333333%; }
      .row .col.push-m1 {
        left: 8.3333333333%; }
      .row .col.offset-m2 {
        margin-left: 16.6666666667%; }
      .row .col.pull-m2 {
        right: 16.6666666667%; }
      .row .col.push-m2 {
        left: 16.6666666667%; }
      .row .col.offset-m3 {
        margin-left: 25%; }
      .row .col.pull-m3 {
        right: 25%; }
      .row .col.push-m3 {
        left: 25%; }
      .row .col.offset-m4 {
        margin-left: 33.3333333333%; }
      .row .col.pull-m4 {
        right: 33.3333333333%; }
      .row .col.push-m4 {
        left: 33.3333333333%; }
      .row .col.offset-m5 {
        margin-left: 41.6666666667%; }
      .row .col.pull-m5 {
        right: 41.6666666667%; }
      .row .col.push-m5 {
        left: 41.6666666667%; }
      .row .col.offset-m6 {
        margin-left: 50%; }
      .row .col.pull-m6 {
        right: 50%; }
      .row .col.push-m6 {
        left: 50%; }
      .row .col.offset-m7 {
        margin-left: 58.3333333333%; }
      .row .col.pull-m7 {
        right: 58.3333333333%; }
      .row .col.push-m7 {
        left: 58.3333333333%; }
      .row .col.offset-m8 {
        margin-left: 66.6666666667%; }
      .row .col.pull-m8 {
        right: 66.6666666667%; }
      .row .col.push-m8 {
        left: 66.6666666667%; }
      .row .col.offset-m9 {
        margin-left: 75%; }
      .row .col.pull-m9 {
        right: 75%; }
      .row .col.push-m9 {
        left: 75%; }
      .row .col.offset-m10 {
        margin-left: 83.3333333333%; }
      .row .col.pull-m10 {
        right: 83.3333333333%; }
      .row .col.push-m10 {
        left: 83.3333333333%; }
      .row .col.offset-m11 {
        margin-left: 91.6666666667%; }
      .row .col.pull-m11 {
        right: 91.6666666667%; }
      .row .col.push-m11 {
        left: 91.6666666667%; }
      .row .col.offset-m12 {
        margin-left: 100%; }
      .row .col.pull-m12 {
        right: 100%; }
      .row .col.push-m12 {
        left: 100%; } }
    @media only screen and (min-width: 993px) {
      .row .col.l1 {
        width: 8.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l2 {
        width: 16.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l3 {
        width: 25%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l4 {
        width: 33.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l5 {
        width: 41.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l6 {
        width: 50%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l7 {
        width: 58.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l8 {
        width: 66.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l9 {
        width: 75%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l10 {
        width: 83.3333333333%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l11 {
        width: 91.6666666667%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.l12 {
        width: 100%;
        margin-left: auto;
        left: auto;
        right: auto; }
      .row .col.offset-l1 {
        margin-left: 8.3333333333%; }
      .row .col.pull-l1 {
        right: 8.3333333333%; }
      .row .col.push-l1 {
        left: 8.3333333333%; }
      .row .col.offset-l2 {
        margin-left: 16.6666666667%; }
      .row .col.pull-l2 {
        right: 16.6666666667%; }
      .row .col.push-l2 {
        left: 16.6666666667%; }
      .row .col.offset-l3 {
        margin-left: 25%; }
      .row .col.pull-l3 {
        right: 25%; }
      .row .col.push-l3 {
        left: 25%; }
      .row .col.offset-l4 {
        margin-left: 33.3333333333%; }
      .row .col.pull-l4 {
        right: 33.3333333333%; }
      .row .col.push-l4 {
        left: 33.3333333333%; }
      .row .col.offset-l5 {
        margin-left: 41.6666666667%; }
      .row .col.pull-l5 {
        right: 41.6666666667%; }
      .row .col.push-l5 {
        left: 41.6666666667%; }
      .row .col.offset-l6 {
        margin-left: 50%; }
      .row .col.pull-l6 {
        right: 50%; }
      .row .col.push-l6 {
        left: 50%; }
      .row .col.offset-l7 {
        margin-left: 58.3333333333%; }
      .row .col.pull-l7 {
        right: 58.3333333333%; }
      .row .col.push-l7 {
        left: 58.3333333333%; }
      .row .col.offset-l8 {
        margin-left: 66.6666666667%; }
      .row .col.pull-l8 {
        right: 66.6666666667%; }
      .row .col.push-l8 {
        left: 66.6666666667%; }
      .row .col.offset-l9 {
        margin-left: 75%; }
      .row .col.pull-l9 {
        right: 75%; }
      .row .col.push-l9 {
        left: 75%; }
      .row .col.offset-l10 {
        margin-left: 83.3333333333%; }
      .row .col.pull-l10 {
        right: 83.3333333333%; }
      .row .col.push-l10 {
        left: 83.3333333333%; }
      .row .col.offset-l11 {
        margin-left: 91.6666666667%; }
      .row .col.pull-l11 {
        right: 91.6666666667%; }
      .row .col.push-l11 {
        left: 91.6666666667%; }
      .row .col.offset-l12 {
        margin-left: 100%; }
      .row .col.pull-l12 {
        right: 100%; }
      .row .col.push-l12 {
        left: 100%; } }

.chip {
  display: inline-block;
  /*height: 32px;*/
  /*font-size: 13px;*/
  /*font-size: initial;*/
  /*font-weight: 500;*/
  /*color: rgba(0,0,0,.6);*/
  line-height: normal;
  padding: 0.5rem;
  border-radius: 16px;
  /*vertical-align: middle;*/
  /*background-color: $chip-bg-color;*/
  /*margin-bottom: $chip-margin;*/
  /*margin-right: $chip-margin;*/ }
  .chip img {
    float: left;
    margin: 0 8px 0 -12px;
    height: 32px;
    width: 32px;
    border-radius: 50%; }
  .chip .close {
    cursor: pointer;
    float: right;
    font-size: 16px;
    line-height: 32px;
    padding-left: 8px; }

.chips {
  border: none;
  border-bottom: 1px solid #9e9e9e;
  box-shadow: none;
  margin: 0 0 20px 0;
  min-height: 45px;
  outline: none;
  transition: all .3s; }
  .chips.focus {
    border-bottom: 1px solid #26a69a;
    box-shadow: 0 1px 0 0 #26a69a; }
  .chips:hover {
    cursor: text; }
  .chips .chip.selected {
    background-color: #26a69a;
    color: #fff; }
  .chips .input {
    background: none;
    border: 0;
    color: rgba(0, 0, 0, 0.6);
    display: inline-block;
    font-size: 1rem;
    height: 3rem;
    line-height: 32px;
    outline: 0;
    margin: 0;
    padding: 0 !important;
    width: 120px !important; }
  .chips .input:focus {
    border: 0 !important;
    box-shadow: none !important; }

.prefix ~ .chips {
  margin-left: 3rem;
  width: 92%;
  width: calc(100% - 3rem); }

.chips:empty ~ label {
  font-size: 0.8rem;
  transform: translateY(-140%); }

.btn, .btn-large,
.btn-flat {
  border: none;
  border-radius: 2px;
  display: inline-block;
  height: 36px;
  line-height: 36px;
  padding: 0 2rem;
  vertical-align: middle;
  -webkit-tap-highlight-color: transparent; }

.btn.disabled, .disabled.btn-large,
.btn-floating.disabled,
.btn-large.disabled,
.btn-flat.disabled,
.btn:disabled,
.btn-large:disabled,
.btn-floating:disabled,
.btn-large:disabled,
.btn-flat:disabled,
.btn[disabled],
[disabled].btn-large,
.btn-floating[disabled],
.btn-large[disabled],
.btn-flat[disabled] {
  pointer-events: none;
  background-color: #DFDFDF;
  box-shadow: none;
  color: #9F9F9F !important;
  cursor: default; }
  .btn.disabled:hover, .disabled.btn-large:hover,
  .btn-floating.disabled:hover,
  .btn-large.disabled:hover,
  .btn-flat.disabled:hover,
  .btn:disabled:hover,
  .btn-large:disabled:hover,
  .btn-floating:disabled:hover,
  .btn-large:disabled:hover,
  .btn-flat:disabled:hover,
  .btn[disabled]:hover,
  [disabled].btn-large:hover,
  .btn-floating[disabled]:hover,
  .btn-large[disabled]:hover,
  .btn-flat[disabled]:hover {
    background-color: #DFDFDF;
    color: #9F9F9F !important; }

.btn, .btn-large,
.btn-floating,
.btn-large,
.btn-flat {
  outline: 0; }
  .btn i, .btn-large i,
  .btn-floating i,
  .btn-large i,
  .btn-flat i {
    /*font-size: $button-font-size;*/
    line-height: inherit; }

.btn:focus, .btn-large:focus,
.btn-floating:focus {
  background-color: #1d7d74; }

.btn, .btn-large {
  text-decoration: none;
  color: #fff;
  background-color: #26a69a;
  text-align: center;
  letter-spacing: .5px;
  transition: .2s ease-out;
  cursor: pointer; }
  .btn:hover, .btn-large:hover {
    background-color: #2bbbad; }

.btn-floating {
  display: inline-block;
  color: #fff;
  position: relative;
  overflow: hidden;
  z-index: 1;
  width: 40px;
  height: 40px;
  line-height: 40px;
  padding: 0;
  background-color: #26a69a;
  border-radius: 50%;
  transition: .3s;
  cursor: pointer;
  vertical-align: middle; }
  .btn-floating i {
    width: inherit;
    display: inline-block;
    text-align: center;
    color: #fff;
    font-size: 1.6rem;
    line-height: 40px; }
  .btn-floating:hover {
    background-color: #26a69a; }
  .btn-floating:before {
    border-radius: 0; }
  .btn-floating.btn-large {
    width: 56px;
    height: 56px; }
    .btn-floating.btn-large i {
      line-height: 56px; }

button.btn-floating {
  border: none; }

.fixed-action-btn {
  position: fixed;
  right: 23px;
  bottom: 23px;
  padding-top: 15px;
  margin-bottom: 0;
  z-index: 998; }
  .fixed-action-btn.active ul {
    visibility: visible; }
  .fixed-action-btn.horizontal {
    padding: 0 0 0 15px; }
    .fixed-action-btn.horizontal ul {
      text-align: right;
      right: 64px;
      top: 50%;
      transform: translateY(-50%);
      height: 100%;
      left: auto;
      width: 500px;
      /*width 100% only goes to width of button container */ }
      .fixed-action-btn.horizontal ul li {
        display: inline-block;
        margin: 15px 15px 0 0; }
  .fixed-action-btn.toolbar {
    padding: 0;
    height: 56px; }
    .fixed-action-btn.toolbar.active > a i {
      opacity: 0; }
    .fixed-action-btn.toolbar ul {
      display: flex;
      top: 0;
      bottom: 0; }
      .fixed-action-btn.toolbar ul li {
        flex: 1;
        display: inline-block;
        margin: 0;
        height: 100%;
        transition: none; }
        .fixed-action-btn.toolbar ul li a {
          display: block;
          overflow: hidden;
          position: relative;
          width: 100%;
          height: 100%;
          background-color: transparent;
          box-shadow: none;
          color: #fff;
          line-height: 56px;
          z-index: 1; }
          .fixed-action-btn.toolbar ul li a i {
            line-height: inherit; }
  .fixed-action-btn ul {
    left: 0;
    right: 0;
    text-align: center;
    position: absolute;
    bottom: 64px;
    margin: 0;
    visibility: hidden; }
    .fixed-action-btn ul li {
      margin-bottom: 15px; }
    .fixed-action-btn ul a.btn-floating {
      opacity: 0; }
  .fixed-action-btn .fab-backdrop {
    position: absolute;
    top: 0;
    left: 0;
    z-index: -1;
    width: 40px;
    height: 40px;
    background-color: #26a69a;
    border-radius: 50%;
    transform: scale(0); }

.btn-flat {
  box-shadow: none;
  background-color: transparent;
  cursor: pointer;
  transition: background-color .2s; }
  .btn-flat:focus, .btn-flat:active {
    background-color: transparent; }
  .btn-flat:focus, .btn-flat:hover {
    background-color: rgba(0, 0, 0, 0.1);
    box-shadow: none; }
  .btn-flat:active {
    background-color: rgba(0, 0, 0, 0.2); }
  .btn-flat.disabled {
    background-color: transparent !important;
    color: #b3b3b3 !important;
    cursor: default; }

.btn-large {
  height: 54px;
  line-height: 54px; }
  .btn-large i {
    font-size: 1.6rem; }

.btn-block {
  display: block; }

.card-panel {
  transition: box-shadow .25s;
  padding: 20px;
  border-radius: 5px;
  background-color: #fff; }

.card {
  position: relative;
  background-color: #fff;
  transition: box-shadow .25s; }
  .card .card-title {
    font-size: 24px;
    font-weight: 300; }
    .card .card-title.activator {
      cursor: pointer; }
  .card.small, .card.medium, .card.large {
    position: relative; }
    .card.small .card-image, .card.medium .card-image, .card.large .card-image {
      max-height: 60%;
      overflow: hidden; }
    .card.small .card-image + .card-content, .card.medium .card-image + .card-content, .card.large .card-image + .card-content {
      max-height: 40%; }
    .card.small .card-content, .card.medium .card-content, .card.large .card-content {
      max-height: 100%;
      overflow: hidden; }
    .card.small .card-action, .card.medium .card-action, .card.large .card-action {
      position: absolute;
      bottom: 0;
      left: 0;
      right: 0; }
  .card.small {
    height: 300px; }
  .card.medium {
    height: 400px; }
  .card.large {
    height: 500px; }
  .card.horizontal {
    display: flex; }
    .card.horizontal.small .card-image, .card.horizontal.medium .card-image, .card.horizontal.large .card-image {
      height: 100%;
      max-height: none;
      overflow: visible; }
      .card.horizontal.small .card-image img, .card.horizontal.medium .card-image img, .card.horizontal.large .card-image img {
        height: 100%; }
    .card.horizontal .card-image {
      max-width: 50%; }
      .card.horizontal .card-image img {
        border-radius: 5px 0 0 5px;
        max-width: 100%;
        width: auto; }
    .card.horizontal .card-stacked {
      display: flex;
      flex-direction: column;
      flex: 1;
      position: relative; }
      .card.horizontal .card-stacked .card-content {
        flex-grow: 1; }
  .card.sticky-action .card-action {
    z-index: 2; }
  .card.sticky-action .card-reveal {
    z-index: 1;
    padding-bottom: 64px; }
  .card .card-image {
    position: relative; }
    .card .card-image img {
      display: block;
      border-radius: 5px 5px 0 0;
      position: relative;
      left: 0;
      right: 0;
      top: 0;
      bottom: 0;
      width: 100%; }
    .card .card-image .card-title {
      color: #fff;
      position: absolute;
      bottom: 0;
      left: 0;
      padding: 20px; }
  .card .card-content {
    padding: 20px;
    border-radius: 0 0 5px 5px; }
    .card .card-content p {
      margin: 0;
      color: inherit; }
    .card .card-content .card-title {
      line-height: 48px; }
  .card .card-action {
    position: relative;
    background-color: inherit;
    border-top: 1px solid rgba(160, 160, 160, 0.2);
    padding: 20px; }
    .card .card-action a:not(.btn):not(.btn-large):not(.btn-large):not(.btn-floating) {
      color: #ffab40;
      margin-right: 20px;
      transition: color .3s ease;
      text-transform: uppercase; }
      .card .card-action a:not(.btn):not(.btn-large):not(.btn-large):not(.btn-floating):hover {
        color: #ffd8a6; }
  .card .card-reveal {
    padding: 20px;
    position: absolute;
    background-color: #fff;
    width: 100%;
    overflow-y: auto;
    left: 0;
    top: 100%;
    height: 100%;
    z-index: 3;
    display: none; }
    .card .card-reveal .card-title {
      cursor: pointer;
      display: block; }

@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic.woff) format("woff"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic.ttf) format("truetype");
  /*curl -s 'https://fonts.gstatic.com/s/robotocondensed/v16/mg0cGfGRUERshzBlvqxeAO6J62hFWZVScRuaNBOo_rA.woff' > RobotoCondensed-LightItalic.woff*/ }
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic.woff) format("woff"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic.ttf) format("truetype");
  /*curl -s 'https://fonts.gstatic.com/s/robotocondensed/v16/BP5K8ZAJv9qEbmuFp8RpJfHZ7IfZvqUgXLEMrfwTXOk.woff' > RobotoCondensed-Italic.woff*/ }
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic.woff) format("woff"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic.ttf) format("truetype");
  /*curl -s 'https://fonts.gstatic.com/s/robotocondensed/v16/mg0cGfGRUERshzBlvqxeAAm1Bdh5PCvFKhAPu2iWX-U.woff' > RobotoCondensed-BoldItalic.woff*/ }
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light.woff) format("woff"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light.ttf) format("truetype");
  /*curl -s 'https://fonts.gstatic.com/s/robotocondensed/v16/b9QBgL0iMZfDSpmcXcE8nNeiznanRB67rGZDYkMvKPc.woff' > RobotoCondensed-Light.woff*/ }
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular.woff) format("woff"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular.ttf) format("truetype");
  /*curl -s 'https://fonts.gstatic.com/s/robotocondensed/v16/Zd2E9abXLFGSr9G3YK2MsFzqCfRpIA3W6ypxnPISCPA.woff' > RobotoCondensed-Regular.woff*/ }
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold.woff) format("woff"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold.ttf) format("truetype");
  /*curl -s 'https://fonts.gstatic.com/s/robotocondensed/v16/b9QBgL0iMZfDSpmcXcE8nCSLrGe-fkSRw2DeVgOoWcQ.woff' > RobotoCondensed-Bold.woff*/ }
/*
find: \(local('\([^)]+\)'),\) url(\(.+?\))
replace: \1 \ncurl -s  '\3' > '
*/
/*
guest@calculate ~/Mojolicious-Plugin-StaticShare/lib/Mojolicious/Plugin/StaticShare/static/fonts/robotocondensed $ grep curl woff2.css 

*/
/* cyrillic-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-cyrillic-ext.woff2) format("woff2");
  unicode-range: U+0460-052F, U+20B4, U+2DE0-2DFF, U+A640-A69F; }
/* cyrillic */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-cyrillic.woff2) format("woff2");
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }
/* greek-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-greek-ext.woff2) format("woff2");
  unicode-range: U+1F00-1FFF; }
/* greek */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-greek.woff2) format("woff2");
  unicode-range: U+0370-03FF; }
/* vietnamese */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-vietnamese.woff2) format("woff2");
  unicode-range: U+0102-0103, U+1EA0-1EF9, U+20AB; }
/* latin-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-latin-ext.woff2) format("woff2");
  unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF; }
/* latin */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 300;
  src: local("Roboto Condensed Light Italic"), local("RobotoCondensed-LightItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-LightItalic-latin.woff2) format("woff2");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215; }
/* cyrillic-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-cyrillic-ext.woff2) format("woff2");
  unicode-range: U+0460-052F, U+20B4, U+2DE0-2DFF, U+A640-A69F; }
/* cyrillic */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-cyrillic.woff2) format("woff2");
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }
/* greek-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-greek-ext.woff2) format("woff2");
  unicode-range: U+1F00-1FFF; }
/* greek */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-greek.woff2) format("woff2");
  unicode-range: U+0370-03FF; }
/* vietnamese */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-vietnamese.woff2) format("woff2");
  unicode-range: U+0102-0103, U+1EA0-1EF9, U+20AB; }
/* latin-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-latin-ext.woff2) format("woff2");
  unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF; }
/* latin */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 400;
  src: local("Roboto Condensed Italic"), local("RobotoCondensed-Italic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Italic-latin.woff2) format("woff2");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215; }
/* cyrillic-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-cyrillic-ext.woff2) format("woff2");
  unicode-range: U+0460-052F, U+20B4, U+2DE0-2DFF, U+A640-A69F; }
/* cyrillic */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-cyrillic.woff2) format("woff2");
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }
/* greek-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-greek-ext.woff2) format("woff2");
  unicode-range: U+1F00-1FFF; }
/* greek */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-greek.woff2) format("woff2");
  unicode-range: U+0370-03FF; }
/* vietnamese */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-vietnamese.woff2) format("woff2");
  unicode-range: U+0102-0103, U+1EA0-1EF9, U+20AB; }
/* latin-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-latin-ext.woff2) format("woff2");
  unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF; }
/* latin */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: italic;
  font-weight: 700;
  src: local("Roboto Condensed Bold Italic"), local("RobotoCondensed-BoldItalic"), url(/static-share/fonts/robotocondensed/RobotoCondensed-BoldItalic-latin.woff2) format("woff2");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215; }
/* cyrillic-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-cyrillic-ext.woff2) format("woff2");
  unicode-range: U+0460-052F, U+20B4, U+2DE0-2DFF, U+A640-A69F; }
/* cyrillic */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-cyrillic.woff2) format("woff2");
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }
/* greek-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-greek-ext.woff2) format("woff2");
  unicode-range: U+1F00-1FFF; }
/* greek */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-greek.woff2) format("woff2");
  unicode-range: U+0370-03FF; }
/* vietnamese */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-vietnamese.woff2) format("woff2");
  unicode-range: U+0102-0103, U+1EA0-1EF9, U+20AB; }
/* latin-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-latin-ext.woff2) format("woff2");
  unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF; }
/* latin */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 300;
  src: local("Roboto Condensed Light"), local("RobotoCondensed-Light"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Light-latin.woff2) format("woff2");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215; }
/* cyrillic-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-cyrillic-ext.woff2) format("woff2");
  unicode-range: U+0460-052F, U+20B4, U+2DE0-2DFF, U+A640-A69F; }
/* cyrillic */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-cyrillic.woff2) format("woff2");
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }
/* greek-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-greek-ext.woff2) format("woff2");
  unicode-range: U+1F00-1FFF; }
/* greek */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-greek.woff2) format("woff2");
  unicode-range: U+0370-03FF; }
/* vietnamese */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-vietnamese.woff2) format("woff2");
  unicode-range: U+0102-0103, U+1EA0-1EF9, U+20AB; }
/* latin-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-latin-ext.woff2) format("woff2");
  unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF; }
/* latin */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 400;
  src: local("Roboto Condensed"), local("RobotoCondensed-Regular"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Regular-latin.woff2) format("woff2");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215; }
/* cyrillic-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-cyrillic-ext.woff2) format("woff2");
  unicode-range: U+0460-052F, U+20B4, U+2DE0-2DFF, U+A640-A69F; }
/* cyrillic */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-cyrillic.woff2) format("woff2");
  unicode-range: U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116; }
/* greek-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-greek-ext.woff2) format("woff2");
  unicode-range: U+1F00-1FFF; }
/* greek */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-greek.woff2) format("woff2");
  unicode-range: U+0370-03FF; }
/* vietnamese */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-vietnamese.woff2) format("woff2");
  unicode-range: U+0102-0103, U+1EA0-1EF9, U+20AB; }
/* latin-ext */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-latin-ext.woff2) format("woff2");
  unicode-range: U+0100-024F, U+1E00-1EFF, U+20A0-20AB, U+20AD-20CF, U+2C60-2C7F, U+A720-A7FF; }
/* latin */
@font-face {
  font-family: 'Roboto Condensed';
  font-style: normal;
  font-weight: 700;
  src: local("Roboto Condensed Bold"), local("RobotoCondensed-Bold"), url(/static-share/fonts/robotocondensed/RobotoCondensed-Bold-latin.woff2) format("woff2");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215; }
a {
  text-decoration: none; }

html {
  line-height: 1.5;
  font-family: "Roboto Condensed";
  font-weight: normal;
  color: rgba(0, 0, 0, 0.87); }
  @media only screen and (min-width: 0) {
    html {
      font-size: 14px; } }
  @media only screen and (min-width: 992px) {
    html {
      font-size: 15px; } }
  @media only screen and (min-width: 1200px) {
    html {
      font-size: 16px; } }

h1, h2, h3, h4, h5, h6 {
  font-weight: 300;
  line-height: 1.1;
  margin: 0.5rem 0; }

h1 a, h2 a, h3 a, h4 a, h5 a, h6 a {
  font-weight: inherit; }

h1 {
  font-size: 2.2rem;
  line-height: 110%; }

h2 {
  font-size: 1.8rem;
  line-height: 110%; }

h3 {
  font-size: 1.6rem;
  line-height: 110%; }

h4 {
  font-size: 1.4rem;
  line-height: 110%; }

h5 {
  font-size: 1.2rem;
  line-height: 110%; }

h6 {
  font-size: 1rem;
  line-height: 110%; }

em {
  font-style: italic; }

strong {
  font-weight: 500; }

small {
  font-size: 75%; }

.light {
  font-weight: 300; }

.thin {
  font-weight: 200; }

.flow-text {
  font-weight: 300; }
  @media only screen and (min-width: 360px) {
    .flow-text {
      font-size: 1.2rem; } }
  @media only screen and (min-width: 390px) {
    .flow-text {
      font-size: 1.224rem; } }
  @media only screen and (min-width: 420px) {
    .flow-text {
      font-size: 1.248rem; } }
  @media only screen and (min-width: 450px) {
    .flow-text {
      font-size: 1.272rem; } }
  @media only screen and (min-width: 480px) {
    .flow-text {
      font-size: 1.296rem; } }
  @media only screen and (min-width: 510px) {
    .flow-text {
      font-size: 1.32rem; } }
  @media only screen and (min-width: 540px) {
    .flow-text {
      font-size: 1.344rem; } }
  @media only screen and (min-width: 570px) {
    .flow-text {
      font-size: 1.368rem; } }
  @media only screen and (min-width: 600px) {
    .flow-text {
      font-size: 1.392rem; } }
  @media only screen and (min-width: 630px) {
    .flow-text {
      font-size: 1.416rem; } }
  @media only screen and (min-width: 660px) {
    .flow-text {
      font-size: 1.44rem; } }
  @media only screen and (min-width: 690px) {
    .flow-text {
      font-size: 1.464rem; } }
  @media only screen and (min-width: 720px) {
    .flow-text {
      font-size: 1.488rem; } }
  @media only screen and (min-width: 750px) {
    .flow-text {
      font-size: 1.512rem; } }
  @media only screen and (min-width: 780px) {
    .flow-text {
      font-size: 1.536rem; } }
  @media only screen and (min-width: 810px) {
    .flow-text {
      font-size: 1.56rem; } }
  @media only screen and (min-width: 840px) {
    .flow-text {
      font-size: 1.584rem; } }
  @media only screen and (min-width: 870px) {
    .flow-text {
      font-size: 1.608rem; } }
  @media only screen and (min-width: 900px) {
    .flow-text {
      font-size: 1.632rem; } }
  @media only screen and (min-width: 930px) {
    .flow-text {
      font-size: 1.656rem; } }
  @media only screen and (min-width: 960px) {
    .flow-text {
      font-size: 1.68rem; } }
  @media only screen and (max-width: 360px) {
    .flow-text {
      font-size: 1.2rem; } }

.modal {
  display: none;
  position: fixed;
  left: 0;
  right: 0;
  bottom: auto;
  background-color: #fafafa;
  padding: 0;
  max-height: 70%;
  width: 55%;
  margin: auto;
  overflow-y: auto;
  border-radius: 2px;
  will-change: top, opacity; }
  @media only screen and (max-width: 992px) {
    .modal {
      width: 80%; } }
  .modal h1, .modal h2, .modal h3, .modal h4 {
    margin-top: 0; }
  .modal .modal-content, .modal .modal-header {
    padding: 24px; }
  .modal .modal-close {
    cursor: pointer; }
  .modal .modal-footer {
    border-radius: 0 0 2px 2px;
    background-color: #fafafa;
    padding: 4px 6px;
    height: 56px;
    width: 100%; }
    .modal .modal-footer .btn, .modal .modal-footer .btn-large, .modal .modal-footer .btn-flat {
      float: right;
      margin: 6px 0; }

.modal-overlay {
  position: fixed;
  z-index: 999;
  top: -100px;
  left: 0;
  bottom: 0;
  right: 0;
  height: 125%;
  width: 100%;
  background: #000;
  display: none;
  will-change: opacity; }

.modal.modal-fixed-footer {
  padding: 0;
  height: 70%; }
  .modal.modal-fixed-footer .modal-content {
    position: absolute;
    height: calc(100% - 56px);
    max-height: 100%;
    width: 100%;
    overflow-y: auto; }
  .modal.modal-fixed-footer .modal-footer {
    border-top: 1px solid rgba(0, 0, 0, 0.1);
    position: absolute;
    bottom: 0; }

.modal.bottom-sheet {
  top: auto;
  bottom: -100%;
  margin: 0;
  width: 100%;
  border-radius: 0;
  will-change: bottom, opacity; }

.dropdown-content {
  background-color: #fff;
  margin: 0;
  display: none;
  min-width: 100px;
  max-height: 650px;
  overflow-y: auto;
  opacity: 0;
  position: absolute;
  z-index: 999;
  will-change: width, height; }
  .dropdown-content li {
    clear: both;
    color: rgba(0, 0, 0, 0.87);
    cursor: pointer;
    min-height: 50px;
    line-height: 1.5rem;
    width: 100%;
    text-align: left;
    text-transform: none; }
    .dropdown-content li:hover, .dropdown-content li.active, .dropdown-content li.selected {
      background-color: #eee; }
    .dropdown-content li.active.selected {
      background-color: #e1e1e1; }
    .dropdown-content li.divider {
      min-height: 0;
      height: 1px; }
    .dropdown-content li > a, .dropdown-content li > span {
      font-size: 16px;
      display: block;
      line-height: 22px;
      padding: 14px 16px; }
    .dropdown-content li > span > label {
      top: 1px;
      left: 0;
      height: 18px; }
    .dropdown-content li > a > i {
      height: inherit;
      line-height: inherit; }

.input-field.col .dropdown-content [type="checkbox"] + label {
  top: 1px;
  left: 0;
  height: 18px; }

#toast-container {
  display: block;
  position: fixed;
  z-index: 10000; }
  @media only screen and (max-width: 600px) {
    #toast-container {
      min-width: 100%;
      bottom: 0%; } }
  @media only screen and (min-width: 601px) and (max-width: 992px) {
    #toast-container {
      left: 5%;
      bottom: 7%;
      max-width: 90%; } }
  @media only screen and (min-width: 993px) {
    #toast-container {
      top: 0;
      left: 7%;
      max-width: 86%;
      width: 100%; } }

.toast {
  border-radius: 2px;
  top: 0;
  width: auto;
  clear: both;
  margin-top: 10px;
  position: relative;
  max-width: 100%;
  height: auto;
  min-height: 48px;
  line-height: 1.5em;
  word-break: break-all;
  background-color: #323232;
  padding: 10px 25px;
  font-size: 1.1rem;
  font-weight: 300;
  color: #fff;
  display: flex;
  align-items: center;
  justify-content: space-between; }
  .toast .btn, .toast .btn-large, .toast .btn-flat {
    margin: 0;
    margin-left: 3rem; }
  .toast.rounded {
    border-radius: 24px; }
  @media only screen and (max-width: 600px) {
    .toast {
      width: 100%;
      border-radius: 0; } }
  @media only screen and (min-width: 601px) and (max-width: 992px) {
    .toast {
      float: left; } }
  @media only screen and (min-width: 993px) {
    .toast {
      float: right; } }

.block {
  display: block; }

.nowrap {
  white-space: nowrap; }

.btn-panel {
  /*position: absolute;
  z-index:1;*/
  border: 1px solid #dadada;
  margin-bottom: 0.3rem; }

.index-file {
  padding: 0.7rem;
  margin-bottom: 1rem; }

.scroll-75vh {
  max-height: 75vh;
  overflow-y: auto; }

.scroll-50vh {
  max-height: 50vh;
  overflow-y: auto; }

#footer {
  /***text-align:right;
  color: lightgray;***/
  position: fixed;
  right: 0.33rem;
  bottom: 0.33rem;
  font-size: 0.51rem; }

#footer .logo {
  height: 1rem;
  vertical-align: text-bottom; }

a.btn-flat svg + span {
  text-transform: uppercase;
  vertical-align: middle; }

.ace_editor {
  border: 1px solid lightgray;
  margin: auto;
  height: calc(70vh);
  width: 100%; }

svg.icon {
  vertical-align: middle; }
  svg.icon.icon15 {
    width: 1.5rem;
    height: 1.5rem; }
  svg.icon.icon12 {
    width: 1.5rem;
    height: 1.5rem; }

input {
  vertical-align: middle; }

.fw500 {
  font-weight: 500; }

.border {
  border: 1px solid; }

.hover-shadow3d:hover, .shadow3d {
  text-shadow: 0 0.032em 0 #b0b0b0, 0px 0.15em 0.11em rgba(0, 0, 0, 0.15), 0px 0.25em 0.021em rgba(0, 0, 0, 0.1), 0px 0.32em 0.32em rgba(0, 0, 0, 0.1); }

/*# sourceMappingURL=main.css.map */
